@@ -1,5 +1,5 @@
 //
-// Copyright 2013-2014 Ettus Research LLC
+// Copyright 2013-2015 Ettus Research LLC
 //
 
 /* Define the USB 2.0 and USB 3.0 enumeration descriptions for the USRP B200
@@ -303,7 +303,7 @@ const uint8_t b200_usb_ss_config_desc[] __attribute__ ((aligned (32))) =
     0x6A,0x00,                      /* Length of this descriptor and all sub descriptors */
     0x05,                           /* Number of interfaces */
     0x01,                           /* Configuration number */
-    0x00,                           /* COnfiguration string index */
+    0x00,                           /* Configuration string index */
     0x80,                           /* Config characteristics - D6: Self power; D5: Remote wakeup */
     0x01,                           /* Lie about the max power consumption (in 8mA unit) : 8mA */
 
@@ -424,6 +424,102 @@ const uint8_t b200_usb_ss_config_desc[] __attribute__ ((aligned (32))) =
 };
 
 
+const uint8_t b200_usb_ss_config_desc_new[] __attribute__ ((aligned (32))) =
+{
+    /* Configuration descriptor */
+    0x09,                           /* Descriptor size */
+    CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
+    0x4F,0x00,                      /* Length of this descriptor and all sub descriptors */
+    0x02,                           /* Number of interfaces */
+    0x01,                           /* Configuration number */
+    0x00,                           /* COnfiguration string index */
+    0x80,                           /* Config characteristics - D6: Self power; D5: Remote wakeup */
+    0x01,                           /* Lie about the max power consumption (in 8mA unit) : 8mA */
+
+    /* Interface descriptor */
+    0x09,                           /* Descriptor size */
+    CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
+    0x00,                           /* Interface number */
+    0x00,                           /* Alternate setting number */
+    0x00,                           /* Number of end points */
+    0xFF,                           /* Interface class */
+    0x00,                           /* Interface sub class */
+    0x00,                           /* Interface protocol code */
+    0x02,                           /* Interface descriptor string index */
+
+    /* Interface descriptor */
+    0x09,                           /* Descriptor size */
+    CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
+    0x01,                           /* Interface number */
+    0x00,                           /* Alternate setting number */
+    0x04,                           /* Number of end points */
+    0xFF,                           /* Interface class */
+    0x00,                           /* Interface sub class */
+    0x00,                           /* Interface protocol code */
+    0x02,                           /* Interface descriptor string index */
+
+    /* Endpoint descriptor for producer EP */
+    0x07,                           /* Descriptor size */
+    CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
+    DATA_ENDPOINT_PRODUCER,         /* Endpoint address and description */
+    CY_U3P_USB_EP_BULK,             /* Bulk endpoint type */
+    0x00,0x04,                      /* Max packet size = 1024 bytes */
+    0x00,                           /* Servicing interval for data transfers : 0 for bulk */
+
+    /* Super speed endpoint companion descriptor for producer EP */
+    0x06,                           /* Descriptor size */
+    CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
+    (USB3_PACKETS_PER_BURST - 1),   /* Max no. of packets in a burst : 0: burst 1 packet at a time */
+    0x00,                           /* Max streams for bulk EP = 0 (No streams) */
+    0x00,0x00,                      /* Service interval for the EP : 0 for bulk */
+
+    /* Endpoint descriptor for consumer EP */
+    0x07,                           /* Descriptor size */
+    CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
+    DATA_ENDPOINT_CONSUMER,         /* Endpoint address and description */
+    CY_U3P_USB_EP_BULK,             /* Bulk endpoint type */
+    0x00,0x04,                      /* Max packet size = 1024 bytes */
+    0x00,                           /* Servicing interval for data transfers : 0 for Bulk */
+
+    /* Super speed endpoint companion descriptor for consumer EP */
+    0x06,                           /* Descriptor size */
+    CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
+    (USB3_PACKETS_PER_BURST - 1),   /* Max no. of packets in a burst : 0: burst 1 packet at a time */
+    0x00,                           /* Max streams for bulk EP = 0 (No streams) */
+    0x00,0x00,                      /* Service interval for the EP : 0 for bulk */
+
+    /* Endpoint descriptor for producer EP */
+    0x07,                           /* Descriptor size */
+    CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
+    CTRL_ENDPOINT_PRODUCER,         /* Endpoint address and description */
+    CY_U3P_USB_EP_BULK,             /* Bulk endpoint type */
+    0x00,0x04,                      /* Max packet size = 1024 bytes */
+    0x00,                           /* Servicing interval for data transfers : 0 for bulk */
+
+    /* Super speed endpoint companion descriptor for producer EP */
+    0x06,                           /* Descriptor size */
+    CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
+    (USB3_PACKETS_PER_BURST - 1),   /* Max no. of packets in a burst : 0: burst 1 packet at a time */
+    0x00,                           /* Max streams for bulk EP = 0 (No streams) */
+    0x00,0x00,                      /* Service interval for the EP : 0 for bulk */
+
+    /* Endpoint descriptor for consumer EP */
+    0x07,                           /* Descriptor size */
+    CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
+    CTRL_ENDPOINT_CONSUMER,         /* Endpoint address and description */
+    CY_U3P_USB_EP_BULK,             /* Bulk endpoint type */
+    0x00,0x04,                      /* Max packet size = 1024 bytes */
+    0x00,                           /* Servicing interval for data transfers : 0 for Bulk */
+
+    /* Super speed endpoint companion descriptor for consumer EP */
+    0x06,                           /* Descriptor size */
+    CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
+    (USB3_PACKETS_PER_BURST - 1),   /* Max no. of packets in a burst : 0: burst 1 packet at a time */
+    0x00,                           /* Max streams for bulk EP = 0 (No streams) */
+    0x00,0x00                       /* Service interval for the EP : 0 for bulk */
+};
+
+
 /* Standard Language ID String Descriptor */
 const uint8_t b200_string_lang_id_desc[] __attribute__ ((aligned (32))) =
     {
@@ -458,6 +554,39 @@ const uint8_t b200_usb_manufacture_desc[] __attribute__ ((aligned (32))) =
         'C',0x00
     };
 
+/* NI Manufacturer String Descriptor */
+const uint8_t niusrp_usb_manufacture_desc[] __attribute__ ((aligned (32))) =
+    {
+        0x36,                           /* Descriptor Size */
+        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
+        'N',0x00,
+        'a',0x00,
+        't',0x00,
+        'i',0x00,
+        'o',0x00,
+        'n',0x00,
+        'a',0x00,
+        'l',0x00,
+        ' ',0x00,
+        'I',0x00,
+        'n',0x00,
+        's',0x00,
+        't',0x00,
+        'r',0x00,
+        'u',0x00,
+        'm',0x00,
+        'e',0x00,
+        'n',0x00,
+        't',0x00,
+        's',0x00,
+        ' ',0x00,
+        'C',0x00,
+        'o',0x00,
+        'r',0x00,
+        'p',0x00,
+        '.',0x00
+    };
+
 
 /* Standard Product String Descriptor */
 const uint8_t b200_usb_product_desc[] __attribute__ ((aligned (32))) =
@@ -475,6 +604,57 @@ const uint8_t b200_usb_product_desc[] __attribute__ ((aligned (32))) =
         '0',0x00
     };
 
+/* NI-USRP 2900 Product String Descriptor */
+const uint8_t niusrp_2900_usb_product_desc[] __attribute__ ((aligned (32))) =
+    {
+        0x1A,                           /* Descriptor Size */
+        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
+        'N',0x00,
+        'I',0x00,
+        ' ',0x00,
+        'U',0x00,
+        'S',0x00,
+        'R',0x00,
+        'P',0x00,
+        '-',0x00,
+        '2',0x00,
+        '9',0x00,
+        '0',0x00,
+        '0',0x00
+    };
+
+/* NI-USRP 2901 Product String Descriptor */
+const uint8_t niusrp_2901_usb_product_desc[] __attribute__ ((aligned (32))) =
+    {
+        0x1A,                           /* Descriptor Size */
+        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
+        'N',0x00,
+        'I',0x00,
+        ' ',0x00,
+        'U',0x00,
+        'S',0x00,
+        'R',0x00,
+        'P',0x00,
+        '-',0x00,
+        '2',0x00,
+        '9',0x00,
+        '0',0x00,
+        '1',0x00
+    };
+
+const uint8_t unknown_desc[] __attribute__ ((aligned (32))) =
+    {
+        0x10,                           /* Descriptor Size */
+        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
+        'U',0x00,
+        'n',0x00,
+        'k',0x00,
+        'n',0x00,
+        'o',0x00,
+        'w',0x00,
+        'n',0x00
+    };
+
 /* Microsoft OS Descriptor. */
 const uint8_t CyFxUsbOSDscr[] __attribute__ ((aligned (32))) =
 {
