@@ -6,7 +6,6 @@
 #include "xge_phy.h"
 #include "ethernet.h"
 #include "chinch.h"
-#include "mdelay.h"
 
 #include <wb_utils.h>
 #include <wb_uart.h>
@@ -218,47 +217,43 @@ void handle_udp_mtu_detect(
 /***********************************************************************
  * Deal with host claims and claim timeout
  **********************************************************************/
-static void handle_claim(void)
+static void handle_claim(uint32_t ticks_now)
 {
+    static const uint32_t CLAIM_TIMEOUT = 2*CPU_CLOCK;      // 2 seconds
+    static uint32_t ticks_last_claim = 0;
     static uint32_t last_time = 0;
-    static size_t timeout = 0;
 
-    //time is 0 if the claim was forfeit
-    if (shmem[X300_FW_SHMEM_CLAIM_TIME] == 0)
+    // Claim status can only change if the claim is active or the claim is renewed.
+    if (shmem[X300_FW_SHMEM_CLAIM_STATUS] != 0 &&
+            (shmem[X300_FW_SHMEM_CLAIM_TIME] == 0 ||
+            ticks_now - ticks_last_claim > CLAIM_TIMEOUT))
     {
-        shmem[X300_FW_SHMEM_CLAIM_STATUS] = 0;
+            // the claim was released or timed out
+            shmem[X300_FW_SHMEM_CLAIM_STATUS] = 0;
+            last_time = shmem[X300_FW_SHMEM_CLAIM_TIME];
     }
-    //if the time changes, reset timeout
     else if (last_time != shmem[X300_FW_SHMEM_CLAIM_TIME])
     {
+        // claim was renewed
         shmem[X300_FW_SHMEM_CLAIM_STATUS] = 1;
-        timeout = 0;
+        last_time = shmem[X300_FW_SHMEM_CLAIM_TIME];
+        ticks_last_claim = ticks_now;
     }
-    //otherwise increment for timeout
-    else timeout++;
-
-    //always stash the last seen time
-    last_time = shmem[X300_FW_SHMEM_CLAIM_TIME];
-
-    //the claim has timed out after 2 seconds
-    if (timeout > 2000) shmem[X300_FW_SHMEM_CLAIM_STATUS] = 0;
 }
 
 /***********************************************************************
  * LED blinky logic and support utilities
  **********************************************************************/
-static uint32_t get_xbar_total(const uint8_t port)
+static uint32_t get_xbar_total(const uint32_t port)
 {
-    #define get_xbar_stat(in_prt, out_prt) \
-        wb_peek32(RB0_BASE+256+(((in_prt)*8+(out_prt))*4))
+    static const uint32_t NUM_PORTS = 16;
     uint32_t total = 0;
-    for (size_t i = 0; i < 8; i++)
+    for (uint32_t i = 0; i < NUM_PORTS; i++)
     {
-        total += get_xbar_stat(port, i);
-    }
-    for (size_t i = 0; i < 8; i++)
-    {
-        total += get_xbar_stat(i, port);
+        wb_poke32(SET0_BASE + SR_RB_ADDR*4, (NUM_PORTS*port + i));
+        total += wb_peek32(RB0_BASE + RB_XBAR*4);
+        wb_poke32(SET0_BASE + SR_RB_ADDR*4, (NUM_PORTS*i + port));
+        total += wb_peek32(RB0_BASE + RB_XBAR*4);
     }
     if (port < 2) //also netstack if applicable
     {
@@ -267,36 +262,17 @@ static uint32_t get_xbar_total(const uint8_t port)
     return total;
 }
 
-static size_t popcntll(uint64_t num)
-{
-    size_t total = 0;
-    for (size_t i = 0; i < sizeof(num)*8; i++)
-    {
-        total += (num >> i) & 0x1;
-    }
-    return total;
-}
-
 static void update_leds(void)
 {
-    //update activity status for all ports
-    uint64_t activity_shreg[8];
-    for (size_t i = 0; i < 8; i++)
-    {
-        static uint32_t last_total[8];
-        const uint32_t total = get_xbar_total(i);
-        activity_shreg[i] <<= 1;
-        activity_shreg[i] |= (total == last_total[i])? 0 : 1;
-        last_total[i] = total;
-    }
+    static uint32_t last_total0 = 0;
+    static uint32_t last_total1 = 0;
+    const uint32_t total0 = get_xbar_total(0);
+    const uint32_t total1 = get_xbar_total(1);
+    const bool act0 = (total0 != last_total0);
+    const bool act1 = (total1 != last_total1);
+    last_total0 = total0;
+    last_total1 = total1;
 
-    static uint32_t counter = 0;
-    counter++;
-
-    const size_t cnt0 = popcntll(activity_shreg[0]);
-    const size_t cnt1 = popcntll(activity_shreg[1]);
-    const bool act0 = cnt0*8 > (counter % 64);
-    const bool act1 = cnt1*8 > (counter % 64);
     const bool link0 = ethernet_get_link_up(0);
     const bool link1 = ethernet_get_link_up(1);
     const bool claimed = shmem[X300_FW_SHMEM_CLAIM_STATUS];
@@ -317,12 +293,14 @@ static void update_leds(void)
 static void garp(void)
 {
     static size_t count = 0;
-    if (count++ < 60000) return; //60 seconds
+    if (count++ < 3000) return; //30 seconds
     count = 0;
     for (size_t e = 0; e < ethernet_ninterfaces(); e++)
     {
-        if (!ethernet_get_link_up(e)) continue;
-        u3_net_stack_send_arp_request(e, u3_net_stack_get_ip_addr(e));
+        if (wb_peek32(SR_ADDR(RB0_BASE, e == 0 ? RB_SFP0_TYPE : RB_SFP1_TYPE)) != RB_SFP_AURORA) {
+            if (!ethernet_get_link_up(e)) continue;
+            u3_net_stack_send_arp_request(e, u3_net_stack_get_ip_addr(e));
+        }
     }
 }
 
@@ -345,12 +323,12 @@ static void handle_uarts(void)
     static uint32_t rxoffset = 0;
     for (int rxch = wb_uart_getc(UART0_BASE); rxch != -1; rxch = wb_uart_getc(UART0_BASE))
     {
-        rxoffset++;
         const int shift = ((rxoffset%4) * 8);
         static uint32_t rxword32 = 0;
         if (shift == 0) rxword32 = 0;
         rxword32 |= ((uint32_t) rxch & 0xFF) << shift;
         rxpool[(rxoffset/4) % NUM_POOL_WORDS32] = rxword32;
+        rxoffset++;
         shmem[X300_FW_SHMEM_UART_RX_INDEX] = rxoffset;
     }
 
@@ -429,7 +407,7 @@ static void handle_link_state(void)
  **********************************************************************/
 int main(void)
 {
-    x300_init();
+    x300_init((x300_eeprom_map_t *)&shmem[X300_FW_SHMEM_IDENT]);
     u3_net_stack_register_udp_handler(X300_FW_COMMS_UDP_PORT, &handle_udp_fw_comms);
     u3_net_stack_register_udp_handler(X300_VITA_UDP_PORT, &handle_udp_prog_framer);
     u3_net_stack_register_udp_handler(X300_FPGA_PROG_UDP_PORT, &handle_udp_fpga_prog);
@@ -439,19 +417,24 @@ int main(void)
 
     while(true)
     {
-        //jobs that happen once every ms
         const uint32_t ticks_now = wb_peek32(SR_ADDR(RB0_BASE, RB_COUNTER));
+
+        // handle the claim every time because any packet processed could
+        // have claimed or released the device and we want the claim status
+        // to be updated immediately to make it atomic from the host perspective
+        handle_claim(ticks_now);
+
+        //jobs that happen once every 10ms
         const uint32_t ticks_passed = ticks_now - last_cronjob;
-        static const uint32_t tick_delta = CPU_CLOCK/1000;
+        static const uint32_t tick_delta = CPU_CLOCK/100;
         if (ticks_passed > tick_delta)
         {
             poll_sfpp_status(0); // Every so often poll XGE Phy to look for SFP+ hotplug events.
             poll_sfpp_status(1); // Every so often poll XGE Phy to look for SFP+ hotplug events.
-            handle_link_state(); //deal with router table update
-            handle_claim(); //deal with the host claim register
+            //handle_link_state(); //deal with router table update
             update_leds(); //run the link and activity leds
             garp(); //send periodic garps
-            last_cronjob = wb_peek32(SR_ADDR(RB0_BASE, RB_COUNTER));
+            last_cronjob = ticks_now;
         }
 
         //run the network stack - poll and handle
