@@ -1,5 +1,5 @@
 //
-// Copyright 2015 Ettus Research LLC
+// Copyright 2015-2016 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@
 #include <uhd/usrp/mboard_eeprom.h>
 #include <uhd/usrp/dboard_eeprom.h>
 #include <uhd/usrp/subdev_spec.h>
+/* version.hpp is safe to include in C: */
+#include <uhd/version.hpp> /* Provides UHD_VERSION */
 
 #include <stdbool.h>
 #include <stdlib.h>
@@ -726,6 +728,83 @@ UHD_API uhd_error uhd_usrp_get_fe_rx_freq_range(
     uhd_meta_range_handle freq_range_out
 );
 
+//! A wildcard for all LO names
+UHD_UNUSED(static const char* UHD_USRP_ALL_LOS) = "all";
+
+//! Get a list of possible LO stage names
+/*
+ * See uhd::usrp::multi_usrp::get_rx_lo_names() for more details.
+ */
+UHD_API uhd_error uhd_usrp_get_rx_lo_names(
+    uhd_usrp_handle h,
+    size_t chan,
+    uhd_string_vector_handle *rx_lo_names_out
+);
+
+//! Set the LO source for the USRP device
+/*
+ * See uhd::usrp::multi_usrp::set_rx_lo_source() for more details.
+ */
+UHD_API uhd_error uhd_usrp_set_rx_lo_source(
+    uhd_usrp_handle h,
+    const char* src,
+    const char* name,
+    size_t chan
+);
+
+//! Get the currently set LO source
+UHD_API uhd_error uhd_usrp_get_rx_lo_source(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    char* rx_lo_source_out,
+    size_t strbuffer_len
+);
+
+//! Get a list of possible LO sources
+UHD_API uhd_error uhd_usrp_get_rx_lo_sources(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    uhd_string_vector_handle *rx_lo_sources_out
+);
+
+//! Set whether the LO used by the USRP device is exported
+/*
+ * See uhd::usrp::multi_usrp::set_rx_lo_enabled() for more details.
+ */
+UHD_API uhd_error uhd_usrp_set_rx_lo_export_enabled(
+    uhd_usrp_handle h,
+    bool enabled,
+    const char* name,
+    size_t chan
+);
+
+//! Returns true if the currently selected LO is being exported.
+UHD_API uhd_error uhd_usrp_get_rx_lo_export_enabled(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    bool* result_out
+);
+
+//! Set the RX LO frequency.
+UHD_API uhd_error uhd_usrp_set_rx_lo_freq(
+    uhd_usrp_handle h,
+    double freq,
+    const char* name,
+    size_t chan,
+    double* coerced_freq_out
+);
+
+//! Get the current RX LO frequency.
+UHD_API uhd_error uhd_usrp_get_rx_lo_freq(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    double* rx_lo_freq_out
+);
+
 //! Set the RX gain for the given channel and name
 UHD_API uhd_error uhd_usrp_set_rx_gain(
     uhd_usrp_handle h,
