@@ -26,11 +26,29 @@
 #include <boost/make_shared.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <boost/thread/thread.hpp> //sleep
+#include <boost/interprocess/mapped_region.hpp>	//get_page_size()
 #include <vector>
 #include <algorithm>    // std::max
 //@TODO: Move the register defs required by the class to a common location
 #include "../usrp/x300/x300_regs.hpp"
 
+#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
+#include <windows.h>
+static UHD_INLINE size_t get_page_size()
+{
+    SYSTEM_INFO si;
+    GetSystemInfo(&si);
+    return si.dwPageSize;
+}
+#else
+#include <unistd.h>
+static UHD_INLINE size_t get_page_size()
+{
+    return size_t(sysconf(_SC_PAGESIZE));
+}
+#endif
+static const size_t page_size = get_page_size();
+
 using namespace uhd;
 using namespace uhd::transport;
 using namespace uhd::niusrprio;
@@ -75,7 +93,6 @@ private:
     nirio_fifo<fifo_data_t>&    _fifo;
     fifo_data_t*                _typed_buffer;
     const size_t                _frame_size;
-    size_t                      _num_frames;
 };
 
 class nirio_zero_copy_msb : public managed_send_buffer
@@ -116,7 +133,6 @@ private:
     nirio_fifo<fifo_data_t>&    _fifo;
     fifo_data_t*                _typed_buffer;
     const size_t                _frame_size;
-    size_t                      _num_frames;
 };
 
 class nirio_zero_copy_impl : public nirio_zero_copy {
@@ -184,11 +200,13 @@ public:
             nirio_status_chain(
                 _recv_fifo->initialize(
                     (_xport_params.recv_frame_size*_xport_params.num_recv_frames)/sizeof(fifo_data_t),
+                    _xport_params.recv_frame_size / sizeof(fifo_data_t),
                     actual_depth, actual_size),
                 status);
             nirio_status_chain(
                 _send_fifo->initialize(
                     (_xport_params.send_frame_size*_xport_params.num_send_frames)/sizeof(fifo_data_t),
+                    _xport_params.send_frame_size / sizeof(fifo_data_t),
                     actual_depth, actual_size),
                 status);
 
@@ -364,6 +382,22 @@ nirio_zero_copy::sptr nirio_zero_copy::make(
     size_t usr_recv_buff_size = static_cast<size_t>(
         hints.cast<double>("recv_buff_size", default_buff_args.num_recv_frames));
 
+    if (hints.has_key("recv_buff_size"))
+    {
+        if (usr_recv_buff_size % page_size != 0)
+        {
+            throw uhd::value_error((boost::format("recv_buff_size must be multiple of %d") % page_size).str());
+        }
+    }
+
+    if (hints.has_key("recv_frame_size") and hints.has_key("num_recv_frames"))
+    {
+        if (usr_num_recv_frames * xport_params.recv_frame_size % page_size != 0)
+        {
+            throw uhd::value_error((boost::format("num_recv_frames * recv_frame_size must be an even multiple of %d") % page_size).str());
+        }
+    }
+
     if (hints.has_key("num_recv_frames") and hints.has_key("recv_buff_size")) {
         if (usr_recv_buff_size < xport_params.recv_frame_size)
             throw uhd::value_error("recv_buff_size must be equal to or greater than (num_recv_frames * recv_frame_size)");
@@ -378,6 +412,11 @@ nirio_zero_copy::sptr nirio_zero_copy::make(
         xport_params.num_recv_frames = usr_num_recv_frames;
     }
 
+    if (xport_params.num_recv_frames * xport_params.recv_frame_size % page_size != 0)
+    {
+        throw uhd::value_error((boost::format("num_recv_frames * recv_frame_size must be an even multiple of %d") % page_size).str());
+    }
+
     //TX
     xport_params.send_frame_size = size_t(hints.cast<double>("send_frame_size", default_buff_args.send_frame_size));
 
@@ -386,6 +425,22 @@ nirio_zero_copy::sptr nirio_zero_copy::make(
     size_t usr_send_buff_size = static_cast<size_t>(
         hints.cast<double>("send_buff_size", default_buff_args.num_send_frames));
 
+    if (hints.has_key("send_buff_size")) 
+    {
+        if (usr_send_buff_size % page_size != 0)
+        {
+            throw uhd::value_error((boost::format("send_buff_size must be multiple of %d") % page_size).str());
+        }
+    }
+
+    if (hints.has_key("send_frame_size") and hints.has_key("num_send_frames"))
+    {
+        if (usr_num_send_frames * xport_params.send_frame_size % page_size != 0)
+        {
+            throw uhd::value_error((boost::format("num_send_frames * send_frame_size must be an even multiple of %d") % page_size).str());
+        }
+    }
+
     if (hints.has_key("num_send_frames") and hints.has_key("send_buff_size")) {
         if (usr_send_buff_size < xport_params.send_frame_size)
             throw uhd::value_error("send_buff_size must be equal to or greater than (num_send_frames * send_frame_size)");
@@ -400,6 +455,11 @@ nirio_zero_copy::sptr nirio_zero_copy::make(
         xport_params.num_send_frames = usr_num_send_frames;
     }
 
+    if (xport_params.num_send_frames * xport_params.send_frame_size % page_size != 0)
+    {
+        throw uhd::value_error((boost::format("num_send_frames * send_frame_size must be an even multiple of %d") % page_size).str());
+    }
+
     return nirio_zero_copy::sptr(new nirio_zero_copy_impl(fpga_session, instance, xport_params));
 }
 
