@@ -35,19 +35,19 @@ enum b200_product_t {
 };
 
 // These are actual USB PIDs (not Ettus Product IDs)
-const static boost::uint16_t B200_VENDOR_ID         = 0x2500;
-const static boost::uint16_t B200_VENDOR_NI_ID      = 0x3923;
-const static boost::uint16_t B200_PRODUCT_ID        = 0x0020;
-const static boost::uint16_t B200MINI_PRODUCT_ID    = 0x0021;
-const static boost::uint16_t B205MINI_PRODUCT_ID    = 0x0022;
-const static boost::uint16_t B200_PRODUCT_NI_ID     = 0x7813;
-const static boost::uint16_t B210_PRODUCT_NI_ID     = 0x7814;
-const static boost::uint16_t FX3_VID                = 0x04b4;
-const static boost::uint16_t FX3_DEFAULT_PID        = 0x00f3;
-const static boost::uint16_t FX3_REENUM_PID         = 0x00f0;
+const static uint16_t B200_VENDOR_ID         = 0x2500;
+const static uint16_t B200_VENDOR_NI_ID      = 0x3923;
+const static uint16_t B200_PRODUCT_ID        = 0x0020;
+const static uint16_t B200MINI_PRODUCT_ID    = 0x0021;
+const static uint16_t B205MINI_PRODUCT_ID    = 0x0022;
+const static uint16_t B200_PRODUCT_NI_ID     = 0x7813;
+const static uint16_t B210_PRODUCT_NI_ID     = 0x7814;
+const static uint16_t FX3_VID                = 0x04b4;
+const static uint16_t FX3_DEFAULT_PID        = 0x00f3;
+const static uint16_t FX3_REENUM_PID         = 0x00f0;
 
 //! Map the USB PID to the product (only for PIDs that map to a single product)
-static const uhd::dict<boost::uint16_t, b200_product_t> B2XX_PID_TO_PRODUCT = boost::assign::map_list_of
+static const uhd::dict<uint16_t, b200_product_t> B2XX_PID_TO_PRODUCT = boost::assign::map_list_of
         (B200_PRODUCT_NI_ID,    B200)
         (B210_PRODUCT_NI_ID,    B210)
         (B200MINI_PRODUCT_ID,   B200MINI)
@@ -57,7 +57,7 @@ static const uhd::dict<boost::uint16_t, b200_product_t> B2XX_PID_TO_PRODUCT = bo
 static const std::string     B200_FW_FILE_NAME = "usrp_b200_fw.hex";
 
 //! Map the EEPROM product ID codes to the product
-static const uhd::dict<boost::uint16_t, b200_product_t> B2XX_PRODUCT_ID = boost::assign::map_list_of
+static const uhd::dict<uint16_t, b200_product_t> B2XX_PRODUCT_ID = boost::assign::map_list_of
         (0x0001,             B200)
         (0x7737,             B200)
         (B200_PRODUCT_NI_ID, B200)
@@ -98,13 +98,13 @@ public:
     static sptr make(uhd::transport::usb_control::sptr usb_ctrl);
 
     //! query the device USB speed (2, 3)
-    virtual boost::uint8_t get_usb_speed(void) = 0;
+    virtual uint8_t get_usb_speed(void) = 0;
 
     //! get the current status of the FX3
-    virtual boost::uint8_t get_fx3_status(void) = 0;
+    virtual uint8_t get_fx3_status(void) = 0;
 
     //! get the current status of the FX3
-    virtual boost::uint16_t get_compat_num(void) = 0;
+    virtual uint16_t get_compat_num(void) = 0;
 
     //! load a firmware image
     virtual void load_firmware(const std::string filestring, bool force=false) = 0;
@@ -119,13 +119,13 @@ public:
     virtual void set_fpga_reset_pin(const bool reset) = 0;
 
     //! load an FPGA image
-    virtual boost::uint32_t load_fpga(const std::string filestring, bool force=false) = 0;
+    virtual uint32_t load_fpga(const std::string filestring, bool force=false) = 0;
 
-    virtual void write_eeprom(boost::uint16_t addr, boost::uint16_t offset, const uhd::byte_vector_t &bytes) = 0;
+    virtual void write_eeprom(uint16_t addr, uint16_t offset, const uhd::byte_vector_t &bytes) = 0;
 
-    virtual uhd::byte_vector_t read_eeprom(boost::uint16_t addr, boost::uint16_t offset, size_t num_bytes) = 0;
+    virtual uhd::byte_vector_t read_eeprom(uint16_t addr, uint16_t offset, size_t num_bytes) = 0;
 
-    static std::string fx3_state_string(boost::uint8_t state);
+    static std::string fx3_state_string(uint8_t state);
 };
 
 
