@@ -36,12 +36,12 @@ using namespace uhd::usrp;
 class ad9361_io_spi : public ad9361_io
 {
 public:
-    ad9361_io_spi(uhd::spi_iface::sptr spi_iface, boost::uint32_t slave_num) :
+    ad9361_io_spi(uhd::spi_iface::sptr spi_iface, uint32_t slave_num) :
         _spi_iface(spi_iface), _slave_num(slave_num) { }
 
     virtual ~ad9361_io_spi() { }
 
-    virtual boost::uint8_t peek8(boost::uint32_t reg)
+    virtual uint8_t peek8(uint32_t reg)
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
 
@@ -49,16 +49,16 @@ public:
         config.mosi_edge = uhd::spi_config_t::EDGE_FALL;
         config.miso_edge = uhd::spi_config_t::EDGE_FALL;    //TODO (Ashish): FPGA SPI workaround. This should be EDGE_RISE
 
-        boost::uint32_t rd_word = AD9361_SPI_READ_CMD |
-                           ((boost::uint32_t(reg) << AD9361_SPI_ADDR_SHIFT) & AD9361_SPI_ADDR_MASK);
+        uint32_t rd_word = AD9361_SPI_READ_CMD |
+                           ((uint32_t(reg) << AD9361_SPI_ADDR_SHIFT) & AD9361_SPI_ADDR_MASK);
 
-        boost::uint32_t val = (_spi_iface->read_spi(_slave_num, config, rd_word, AD9361_SPI_NUM_BITS));
+        uint32_t val = (_spi_iface->read_spi(_slave_num, config, rd_word, AD9361_SPI_NUM_BITS));
         val &= 0xFF;
 
-        return static_cast<boost::uint8_t>(val);
+        return static_cast<uint8_t>(val);
     }
 
-    virtual void poke8(boost::uint32_t reg, boost::uint8_t val)
+    virtual void poke8(uint32_t reg, uint8_t val)
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
 
@@ -66,24 +66,24 @@ public:
         config.mosi_edge = uhd::spi_config_t::EDGE_FALL;
         config.miso_edge = uhd::spi_config_t::EDGE_FALL;    //TODO (Ashish): FPGA SPI workaround. This should be EDGE_RISE
 
-        boost::uint32_t wr_word = AD9361_SPI_WRITE_CMD |
-                           ((boost::uint32_t(reg) << AD9361_SPI_ADDR_SHIFT) & AD9361_SPI_ADDR_MASK) |
-                           ((boost::uint32_t(val) << AD9361_SPI_DATA_SHIFT) & AD9361_SPI_DATA_MASK);
+        uint32_t wr_word = AD9361_SPI_WRITE_CMD |
+                           ((uint32_t(reg) << AD9361_SPI_ADDR_SHIFT) & AD9361_SPI_ADDR_MASK) |
+                           ((uint32_t(val) << AD9361_SPI_DATA_SHIFT) & AD9361_SPI_DATA_MASK);
         _spi_iface->write_spi(_slave_num, config, wr_word, AD9361_SPI_NUM_BITS);
     }
 
 private:
     uhd::spi_iface::sptr    _spi_iface;
-    boost::uint32_t         _slave_num;
+    uint32_t         _slave_num;
     boost::mutex            _mutex;
 
-    static const boost::uint32_t AD9361_SPI_WRITE_CMD  = 0x00800000;
-    static const boost::uint32_t AD9361_SPI_READ_CMD   = 0x00000000;
-    static const boost::uint32_t AD9361_SPI_ADDR_MASK  = 0x003FFF00;
-    static const boost::uint32_t AD9361_SPI_ADDR_SHIFT = 8;
-    static const boost::uint32_t AD9361_SPI_DATA_MASK  = 0x000000FF;
-    static const boost::uint32_t AD9361_SPI_DATA_SHIFT = 0;
-    static const boost::uint32_t AD9361_SPI_NUM_BITS   = 24;
+    static const uint32_t AD9361_SPI_WRITE_CMD  = 0x00800000;
+    static const uint32_t AD9361_SPI_READ_CMD   = 0x00000000;
+    static const uint32_t AD9361_SPI_ADDR_MASK  = 0x003FFF00;
+    static const uint32_t AD9361_SPI_ADDR_SHIFT = 8;
+    static const uint32_t AD9361_SPI_DATA_MASK  = 0x000000FF;
+    static const uint32_t AD9361_SPI_DATA_SHIFT = 0;
+    static const uint32_t AD9361_SPI_NUM_BITS   = 24;
 };
 
 /***********************************************************************
@@ -93,18 +93,30 @@ class ad9361_ctrl_impl : public ad9361_ctrl
 {
 public:
     ad9361_ctrl_impl(ad9361_params::sptr client_settings, ad9361_io::sptr io_iface):
-        _device(client_settings, io_iface)
+        _device(client_settings, io_iface), _safe_spi(io_iface), _timed_spi(io_iface)
     {
         _device.initialize();
     }
 
+    void set_timed_spi(uhd::spi_iface::sptr spi_iface, uint32_t slave_num)
+    {
+        _timed_spi = boost::make_shared<ad9361_io_spi>(spi_iface, slave_num);
+        _use_timed_spi();
+    }
+
+    void set_safe_spi(uhd::spi_iface::sptr spi_iface, uint32_t slave_num)
+    {
+        _safe_spi = boost::make_shared<ad9361_io_spi>(spi_iface, slave_num);
+    }
+
     double set_gain(const std::string &which, const double value)
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
 
         ad9361_device_t::direction_t direction = _get_direction_from_antenna(which);
         ad9361_device_t::chain_t chain =_get_chain_from_antenna(which);
-        return _device.set_gain(direction, chain, value);
+        double return_val = _device.set_gain(direction, chain, value);
+        return return_val;
     }
 
     void set_agc(const std::string &which, bool enable)
@@ -112,7 +124,7 @@ public:
         boost::lock_guard<boost::mutex> lock(_mutex);
 
         ad9361_device_t::chain_t chain =_get_chain_from_antenna(which);
-         _device.set_agc(chain, enable);
+        _device.set_agc(chain, enable);
     }
 
     void set_agc_mode(const std::string &which, const std::string &mode)
@@ -133,6 +145,9 @@ public:
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
 
+        // Changing clock rate will disrupt AD9361's sample clock
+        _use_safe_spi();
+
         //clip to known bounds
         const meta_range_t clock_rate_range = ad9361_ctrl::get_clock_rate_range();
         const double clipped_rate = clock_rate_range.clip(rate);
@@ -144,7 +159,11 @@ public:
             ) % (rate/1e6) % (clipped_rate/1e6) << std::endl;
         }
 
-        return _device.set_clock_rate(clipped_rate);
+        double return_rate = _device.set_clock_rate(clipped_rate);
+
+        _use_timed_spi();
+
+        return return_rate;
     }
 
     //! set which RX and TX chains/antennas are active
@@ -152,7 +171,11 @@ public:
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
 
+        // If both RX chains are disabled then the AD9361's sample clock is disabled
+        _use_safe_spi();
         _device.set_active_chains(tx1, tx2, rx1, rx2);
+        _use_timed_spi();
+
     }
 
     //! tune the given frontend, return the exact value
@@ -166,7 +189,8 @@ public:
         const double value = ad9361_ctrl::get_rf_freq_range().clip(clipped_freq);
 
         ad9361_device_t::direction_t direction = _get_direction_from_antenna(which);
-        return _device.tune(direction, value);
+        double return_val = _device.tune(direction, value);
+        return return_val;
     }
 
     //! get the current frequency for the given frontend
@@ -283,16 +307,28 @@ private:
         return ad9361_device_t::CHAIN_1;
     }
 
-    ad9361_device_t _device;
-    boost::mutex    _mutex;
+    void _use_safe_spi() {
+        _device.set_io_iface(_safe_spi);
+    }
+
+    void _use_timed_spi() {
+        _device.set_io_iface(_timed_spi);
+    }
+
+    ad9361_device_t         _device;
+    ad9361_io::sptr         _safe_spi;      // SPI core that uses an always available clock
+    ad9361_io::sptr         _timed_spi;     // SPI core that has a dependency on the AD9361's sample clock (i.e. radio clk)
+    boost::mutex            _mutex;
 };
 
 //----------------------------------------------------------------------
 // Make an instance of the AD9361 Control interface
 //----------------------------------------------------------------------
 ad9361_ctrl::sptr ad9361_ctrl::make_spi(
-    ad9361_params::sptr client_settings, uhd::spi_iface::sptr spi_iface, boost::uint32_t slave_num)
-{
+    ad9361_params::sptr client_settings,
+    uhd::spi_iface::sptr spi_iface,
+    uint32_t slave_num
+) {
     boost::shared_ptr<ad9361_io_spi> spi_io_iface = boost::make_shared<ad9361_io_spi>(spi_iface, slave_num);
     return sptr(new ad9361_ctrl_impl(client_settings, spi_io_iface));
 }
