@@ -56,7 +56,13 @@ public:
 
     //! make a new codec control object
     static sptr make_spi(
-        ad9361_params::sptr client_settings, uhd::spi_iface::sptr spi_iface, boost::uint32_t slave_num);
+        ad9361_params::sptr client_settings,
+        uhd::spi_iface::sptr spi_iface,
+        uint32_t slave_num
+    );
+
+    virtual void set_timed_spi(uhd::spi_iface::sptr spi_iface, uint32_t slave_num) = 0;
+    virtual void set_safe_spi(uhd::spi_iface::sptr spi_iface, uint32_t slave_num) = 0;
 
     //! Get a list of gain names for RX or TX
     static std::vector<std::string> get_gain_names(const std::string &/*which*/)
@@ -89,8 +95,10 @@ public:
     //! get the clock rate range for the frontend
     static uhd::meta_range_t get_clock_rate_range(void)
     {
-        //return uhd::meta_range_t(220e3, 61.44e6);
-        return uhd::meta_range_t(5e6, ad9361_device_t::AD9361_MAX_CLOCK_RATE); //5 MHz DCM low end
+        return uhd::meta_range_t(
+                ad9361_device_t::AD9361_MIN_CLOCK_RATE,
+                ad9361_device_t::AD9361_MAX_CLOCK_RATE
+        );
     }
 
     //! set the filter bandwidth for the frontend's analog low pass
