@@ -20,35 +20,14 @@
 
 #include <uhd/config.hpp>
 #include <uhd/usrp/dboard_iface.hpp>
+#include <uhd/usrp/gpio_defs.hpp>
 #include <boost/assign.hpp>
-#include <boost/cstdint.hpp>
+#include <stdint.h>
 #include <boost/utility.hpp>
 #include <boost/shared_ptr.hpp>
 #include <uhd/types/wb_iface.hpp>
 #include <map>
 
-typedef enum {
-    GPIO_CTRL,
-    GPIO_DDR,
-    GPIO_OUT,
-    GPIO_ATR_0X,
-    GPIO_ATR_RX,
-    GPIO_ATR_TX,
-    GPIO_ATR_XX
-} gpio_attr_t;
-
-typedef std::map<gpio_attr_t,std::string> gpio_attr_map_t;
-static const gpio_attr_map_t gpio_attr_map =
-    boost::assign::map_list_of
-        (GPIO_CTRL,   "CTRL")
-        (GPIO_DDR,    "DDR")
-        (GPIO_OUT,    "OUT")
-        (GPIO_ATR_0X, "ATR_0X")
-        (GPIO_ATR_RX, "ATR_RX")
-        (GPIO_ATR_TX, "ATR_TX")
-        (GPIO_ATR_XX, "ATR_XX")
-;
-
 class gpio_core_200 : boost::noncopyable{
 public:
     typedef boost::shared_ptr<gpio_core_200> sptr;
@@ -59,20 +38,32 @@ public:
     virtual ~gpio_core_200(void) = 0;
 
     //! makes a new GPIO core from iface and slave base
-    static sptr make(uhd::wb_iface::sptr iface, const size_t base, const size_t rb_addr);
+    static sptr make(
+        uhd::wb_iface::sptr iface, const size_t base, const size_t rb_addr);
 
     //! 1 = ATR
-    virtual void set_pin_ctrl(const unit_t unit, const boost::uint16_t value) = 0;
+    virtual void set_pin_ctrl(
+        const unit_t unit, const uint16_t value, const uint16_t mask) = 0;
 
-    virtual void set_atr_reg(const unit_t unit, const atr_reg_t atr, const boost::uint16_t value) = 0;
+    virtual uint16_t get_pin_ctrl(unit_t unit) = 0;
+
+    virtual void set_atr_reg(
+        const unit_t unit, const atr_reg_t atr, const uint16_t value, const uint16_t mask) = 0;
+
+    virtual uint16_t get_atr_reg(unit_t unit, atr_reg_t reg) = 0;
 
     //! 1 = OUTPUT
-    virtual void set_gpio_ddr(const unit_t unit, const boost::uint16_t value) = 0;
+    virtual void set_gpio_ddr(
+        const unit_t unit, const uint16_t value, const uint16_t mask) = 0;
 
-    virtual void set_gpio_out(const unit_t unit, const boost::uint16_t value) = 0;
+    virtual uint16_t get_gpio_ddr(unit_t unit) = 0;
 
-    virtual boost::uint16_t read_gpio(const unit_t unit) = 0;
+    virtual void set_gpio_out(
+        const unit_t unit, const uint16_t value, const uint16_t mask) = 0;
 
+    virtual uint16_t get_gpio_out(unit_t unit) = 0;
+
+    virtual uint16_t read_gpio(const unit_t unit) = 0;
 };
 
 //! Simple wrapper for 32 bit write only
@@ -86,9 +77,11 @@ public:
 
     static sptr make(uhd::wb_iface::sptr iface, const size_t);
 
-    virtual void set_atr_reg(const atr_reg_t atr, const boost::uint32_t value) = 0;
+    virtual void set_ddr_reg() = 0;
 
-    virtual void set_all_regs(const boost::uint32_t value) = 0;
+    virtual void set_atr_reg(const atr_reg_t atr, const uint32_t value) = 0;
+
+    virtual void set_all_regs(const uint32_t value) = 0;
 };
 
 #endif /* INCLUDED_LIBUHD_USRP_GPIO_CORE_200_HPP */
