@@ -69,14 +69,14 @@ public:
 
     void set_clock_rate(const double rate)
     {
-        static const boost::uint32_t i2c_datarate = 400000;
-        boost::uint16_t prescaler = boost::uint16_t(rate / (i2c_datarate*5) - 1);
+        static const uint32_t i2c_datarate = 400000;
+        uint16_t prescaler = uint16_t(rate / (i2c_datarate*5) - 1);
         _iface->poke32(REG_I2C_PRESCALER_LO, prescaler & 0xFF);
         _iface->poke32(REG_I2C_PRESCALER_HI, (prescaler >> 8) & 0xFF);
     }
 
     void write_i2c(
-        boost::uint16_t addr,
+        uint16_t addr,
         const byte_vector_t &bytes
     ){
         _iface->poke32(REG_I2C_DATA, (addr << 1) | 0); //addr and read bit (0)
@@ -99,7 +99,7 @@ public:
     }
 
     byte_vector_t read_i2c(
-        boost::uint16_t addr,
+        uint16_t addr,
         size_t num_bytes
     ){
         byte_vector_t bytes;
@@ -118,16 +118,16 @@ public:
         for (size_t i = 0; i < num_bytes; i++) {
             _iface->poke32(REG_I2C_CMD_STATUS, I2C_CMD_RD | ((num_bytes == i+1) ? (I2C_CMD_STOP | I2C_CMD_NACK) : 0));
             i2c_wait();
-            bytes.push_back(boost::uint8_t(_iface->peek32(REG_I2C_DATA)));
+            bytes.push_back(uint8_t(_iface->peek32(REG_I2C_DATA)));
         }
         return bytes;
     }
 
     //override read_eeprom so we can write once, read all N bytes
     //the default implementation calls read i2c once per byte
-    byte_vector_t read_eeprom(boost::uint16_t addr, boost::uint16_t offset, size_t num_bytes)
+    byte_vector_t read_eeprom(uint16_t addr, uint16_t offset, size_t num_bytes)
     {
-        this->write_i2c(addr, byte_vector_t(1, boost::uint8_t(offset)));
+        this->write_i2c(addr, byte_vector_t(1, uint8_t(offset)));
         return this->read_i2c(addr, num_bytes);
     }
 
