@@ -16,6 +16,7 @@
 //
 
 #include "rx_dsp_core_3000.hpp"
+#include "dsp_core_utils.hpp"
 #include <uhd/types/dict.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/utils/math.hpp>
@@ -24,7 +25,6 @@
 #include <boost/assign/list_of.hpp>
 #include <boost/thread/thread.hpp> //thread sleep
 #include <boost/math/special_functions/round.hpp>
-#include <boost/math/special_functions/sign.hpp>
 #include <algorithm>
 #include <cmath>
 
@@ -69,6 +69,7 @@ public:
         _scaling_adjustment = 1.0;
         _dsp_extra_scaling = 1.0;
         _tick_rate = 1.0;
+        _dsp_freq_offset = 0.0;
     }
 
     ~rx_dsp_core_3000_impl(void)
@@ -79,17 +80,41 @@ public:
         )
     }
 
-    void set_mux(const std::string &mode, const bool fe_swapped, const bool invert_i, const bool invert_q){
-        static const uhd::dict<std::string, boost::uint32_t> mode_to_mux = boost::assign::map_list_of
-            ("IQ", 0)
-            ("QI", FLAG_DSP_RX_MUX_SWAP_IQ)
-            ("I", FLAG_DSP_RX_MUX_REAL_MODE)
-            ("Q", FLAG_DSP_RX_MUX_SWAP_IQ | FLAG_DSP_RX_MUX_REAL_MODE)
-        ;
-        _iface->poke32(REG_DSP_RX_MUX, mode_to_mux[mode]
-            | (fe_swapped ? FLAG_DSP_RX_MUX_SWAP_IQ : 0)
-            | (invert_i ? FLAG_DSP_RX_MUX_INVERT_I : 0)
-            | (invert_q ? FLAG_DSP_RX_MUX_INVERT_Q : 0));
+    void set_mux(const uhd::usrp::fe_connection_t& fe_conn){
+        uint32_t reg_val = 0;
+        switch (fe_conn.get_sampling_mode()) {
+        case uhd::usrp::fe_connection_t::REAL:
+        case uhd::usrp::fe_connection_t::HETERODYNE:
+            reg_val = FLAG_DSP_RX_MUX_REAL_MODE;
+            break;
+        default:
+            reg_val = 0;
+            break;
+        }
+
+        if (fe_conn.is_iq_swapped()) reg_val |= FLAG_DSP_RX_MUX_SWAP_IQ;
+        if (fe_conn.is_i_inverted()) reg_val |= FLAG_DSP_RX_MUX_INVERT_I;
+        if (fe_conn.is_q_inverted()) reg_val |= FLAG_DSP_RX_MUX_INVERT_Q;
+
+        _iface->poke32(REG_DSP_RX_MUX, reg_val);
+
+        if (fe_conn.get_sampling_mode() == uhd::usrp::fe_connection_t::HETERODYNE) {
+            //1. Remember the sign of the IF frequency.
+            //   It will be discarded in the next step
+            int if_freq_sign = boost::math::sign(fe_conn.get_if_freq());
+            //2. Map IF frequency to the range [0, _tick_rate)
+            double if_freq = std::abs(std::fmod(fe_conn.get_if_freq(), _tick_rate));
+            //3. Map IF frequency to the range [-_tick_rate/2, _tick_rate/2)
+            //   This is the aliased frequency
+            if (if_freq > (_tick_rate / 2.0)) {
+                if_freq -= _tick_rate;
+            }
+            //4. Set DSP offset to spin the signal in the opposite
+            //   direction as the aliased frequency
+            _dsp_freq_offset = if_freq * (-if_freq_sign);
+        } else {
+            _dsp_freq_offset = 0.0;
+        }
     }
 
     void set_tick_rate(const double rate){
@@ -97,8 +122,8 @@ public:
     }
 
     void set_link_rate(const double rate){
-        //_link_rate = rate/sizeof(boost::uint32_t); //in samps/s
-        _link_rate = rate/sizeof(boost::uint16_t); //in samps/s (allows for 8sc)
+        //_link_rate = rate/sizeof(uint32_t); //in samps/s
+        _link_rate = rate/sizeof(uint16_t); //in samps/s (allows for 8sc)
     }
 
     uhd::meta_range_t get_host_rates(void){
@@ -198,7 +223,7 @@ public:
     // Further more factor in OTW format which adds further gain factor to weight output samples correctly.
     void update_scalar(void){
         const double target_scalar = (1 << (_is_b200 ? 16 : 15))*_scaling_adjustment/_dsp_extra_scaling;
-        const boost::int32_t actual_scalar = boost::math::iround(target_scalar);
+        const int32_t actual_scalar = boost::math::iround(target_scalar);
         // Calculate the error introduced by using integer representation for the scalar, can be corrected in host later.
         _fxpt_scalar_correction = target_scalar/actual_scalar;
         // Write DDC with scaling correction for CIC and CORDIC that maximizes dynamic range in 32/16/12/8bits.
@@ -209,47 +234,18 @@ public:
         return _fxpt_scalar_correction*_host_extra_scaling/32767.;
     }
 
-    double set_freq(const double freq_){
-        //correct for outside of rate (wrap around)
-        double freq = std::fmod(freq_, _tick_rate);
-        if (std::abs(freq) > _tick_rate/2.0)
-            freq -= boost::math::sign(freq)*_tick_rate;
-
-        //confirm that the target frequency is within range of the CORDIC
-        UHD_ASSERT_THROW(std::abs(freq) <= _tick_rate/2.0);
-
-        /* Now calculate the frequency word. It is possible for this calculation
-         * to cause an overflow. As the requested DSP frequency approaches the
-         * master clock rate, that ratio multiplied by the scaling factor (2^32)
-         * will generally overflow within the last few kHz of tunable range.
-         * Thus, we check to see if the operation will overflow before doing it,
-         * and if it will, we set it to the integer min or max of this system.
-         */
-        boost::int32_t freq_word = 0;
-
-        static const double scale_factor = std::pow(2.0, 32);
-        if((freq / _tick_rate) >= (uhd::math::BOOST_INT32_MAX / scale_factor)) {
-            /* Operation would have caused a positive overflow of int32. */
-            freq_word = uhd::math::BOOST_INT32_MAX;
-
-        } else if((freq / _tick_rate) <= (uhd::math::BOOST_INT32_MIN / scale_factor)) {
-            /* Operation would have caused a negative overflow of int32. */
-            freq_word = uhd::math::BOOST_INT32_MIN;
-
-        } else {
-            /* The operation is safe. Perform normally. */
-            freq_word = boost::int32_t(boost::math::round((freq / _tick_rate) * scale_factor));
-        }
-
-        //program the frequency word into the device DSP
-        const double actual_freq = (double(freq_word) / scale_factor) * _tick_rate;
-        _iface->poke32(REG_DSP_RX_FREQ, boost::uint32_t(freq_word));
-
+    double set_freq(const double requested_freq){
+        double actual_freq;
+        int32_t freq_word;
+        get_freq_and_freq_word(requested_freq + _dsp_freq_offset, _tick_rate, actual_freq, freq_word);
+        _iface->poke32(REG_DSP_RX_FREQ, uint32_t(freq_word));
         return actual_freq;
     }
 
     uhd::meta_range_t get_freq_range(void){
-        return uhd::meta_range_t(-_tick_rate/2, +_tick_rate/2, _tick_rate/std::pow(2.0, 32));
+        //Too keep the DSP range symmetric about 0, we use abs(_dsp_freq_offset)
+        const double offset = std::abs<double>(_dsp_freq_offset);
+        return uhd::meta_range_t(-(_tick_rate-offset)/2, +(_tick_rate-offset)/2, _tick_rate/std::pow(2.0, 32));
     }
 
     void setup(const uhd::stream_args_t &stream_args){
@@ -284,18 +280,18 @@ public:
     void populate_subtree(property_tree::sptr subtree)
     {
         subtree->create<meta_range_t>("rate/range")
-            .publish(boost::bind(&rx_dsp_core_3000::get_host_rates, this))
+            .set_publisher(boost::bind(&rx_dsp_core_3000::get_host_rates, this))
         ;
         subtree->create<double>("rate/value")
             .set(DEFAULT_RATE)
-            .coerce(boost::bind(&rx_dsp_core_3000::set_host_rate, this, _1))
+            .set_coercer(boost::bind(&rx_dsp_core_3000::set_host_rate, this, _1))
         ;
         subtree->create<double>("freq/value")
             .set(DEFAULT_CORDIC_FREQ)
-            .coerce(boost::bind(&rx_dsp_core_3000::set_freq, this, _1))
+            .set_coercer(boost::bind(&rx_dsp_core_3000::set_freq, this, _1))
         ;
         subtree->create<meta_range_t>("freq/range")
-            .publish(boost::bind(&rx_dsp_core_3000::get_freq_range, this))
+            .set_publisher(boost::bind(&rx_dsp_core_3000::get_freq_range, this))
         ;
     }
 
@@ -305,6 +301,7 @@ private:
     const bool _is_b200;    //TODO: Obsolete this when we switch to the new DDC on the B200
     double _tick_rate, _link_rate;
     double _scaling_adjustment, _dsp_extra_scaling, _host_extra_scaling, _fxpt_scalar_correction;
+    double _dsp_freq_offset;
 };
 
 rx_dsp_core_3000::sptr rx_dsp_core_3000::make(wb_iface::sptr iface, const size_t dsp_base, const bool is_b200 /* = false */)
