@@ -16,13 +16,13 @@
 //
 
 #include "tx_dsp_core_3000.hpp"
+#include "dsp_core_utils.hpp"
 #include <uhd/types/dict.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/utils/math.hpp>
 #include <uhd/utils/msg.hpp>
 #include <boost/assign/list_of.hpp>
 #include <boost/math/special_functions/round.hpp>
-#include <boost/math/special_functions/sign.hpp>
 #include <boost/thread/thread.hpp> //sleep
 #include <algorithm>
 #include <cmath>
@@ -66,8 +66,8 @@ public:
     }
 
     void set_link_rate(const double rate){
-        //_link_rate = rate/sizeof(boost::uint32_t); //in samps/s
-        _link_rate = rate/sizeof(boost::uint16_t); //in samps/s (allows for 8sc)
+        //_link_rate = rate/sizeof(uint32_t); //in samps/s
+        _link_rate = rate/sizeof(uint16_t); //in samps/s (allows for 8sc)
     }
 
     uhd::meta_range_t get_host_rates(void){
@@ -127,7 +127,7 @@ public:
   // Further more factor in OTW format which adds further gain factor to weight output samples correctly.
     void update_scalar(void){
         const double target_scalar = (1 << 16)*_scaling_adjustment/_dsp_extra_scaling;
-        const boost::int32_t actual_scalar = boost::math::iround(target_scalar);
+        const int32_t actual_scalar = boost::math::iround(target_scalar);
         _fxpt_scalar_correction = target_scalar/actual_scalar; //should be small
         _iface->poke32(REG_DSP_TX_SCALE_IQ, actual_scalar);
     }
@@ -136,42 +136,11 @@ public:
         return _fxpt_scalar_correction*_host_extra_scaling*32767.;
     }
 
-    double set_freq(const double freq_){
-        //correct for outside of rate (wrap around)
-        double freq = std::fmod(freq_, _tick_rate);
-        if (std::abs(freq) > _tick_rate/2.0)
-            freq -= boost::math::sign(freq)*_tick_rate;
-
-        //confirm that the target frequency is within range of the CORDIC
-        UHD_ASSERT_THROW(std::abs(freq) <= _tick_rate/2.0);
-
-        /* Now calculate the frequency word. It is possible for this calculation
-         * to cause an overflow. As the requested DSP frequency approaches the
-         * master clock rate, that ratio multiplied by the scaling factor (2^32)
-         * will generally overflow within the last few kHz of tunable range.
-         * Thus, we check to see if the operation will overflow before doing it,
-         * and if it will, we set it to the integer min or max of this system.
-         */
-        boost::int32_t freq_word = 0;
-
-        static const double scale_factor = std::pow(2.0, 32);
-        if((freq / _tick_rate) >= (uhd::math::BOOST_INT32_MAX / scale_factor)) {
-            /* Operation would have caused a positive overflow of int32. */
-            freq_word = uhd::math::BOOST_INT32_MAX;
-
-        } else if((freq / _tick_rate) <= (uhd::math::BOOST_INT32_MIN / scale_factor)) {
-            /* Operation would have caused a negative overflow of int32. */
-            freq_word = uhd::math::BOOST_INT32_MIN;
-
-        } else {
-            /* The operation is safe. Perform normally. */
-            freq_word = boost::int32_t(boost::math::round((freq / _tick_rate) * scale_factor));
-        }
-
-        //program the frequency word into the device DSP
-        const double actual_freq = (double(freq_word) / scale_factor) * _tick_rate;
-        _iface->poke32(REG_DSP_TX_FREQ, boost::uint32_t(freq_word));
-
+    double set_freq(const double requested_freq) {
+        double actual_freq;
+        int32_t freq_word;
+        get_freq_and_freq_word(requested_freq, _tick_rate, actual_freq, freq_word);
+        _iface->poke32(REG_DSP_TX_FREQ, uint32_t(freq_word));
         return actual_freq;
     }
 
@@ -211,18 +180,18 @@ public:
     void populate_subtree(property_tree::sptr subtree)
     {
         subtree->create<meta_range_t>("rate/range")
-            .publish(boost::bind(&tx_dsp_core_3000::get_host_rates, this))
+            .set_publisher(boost::bind(&tx_dsp_core_3000::get_host_rates, this))
         ;
         subtree->create<double>("rate/value")
             .set(DEFAULT_RATE)
-            .coerce(boost::bind(&tx_dsp_core_3000::set_host_rate, this, _1))
+            .set_coercer(boost::bind(&tx_dsp_core_3000::set_host_rate, this, _1))
         ;
         subtree->create<double>("freq/value")
             .set(DEFAULT_CORDIC_FREQ)
-            .coerce(boost::bind(&tx_dsp_core_3000::set_freq, this, _1))
+            .set_coercer(boost::bind(&tx_dsp_core_3000::set_freq, this, _1))
         ;
         subtree->create<meta_range_t>("freq/range")
-            .publish(boost::bind(&tx_dsp_core_3000::get_freq_range, this))
+            .set_publisher(boost::bind(&tx_dsp_core_3000::get_freq_range, this))
         ;
     }
 
