@@ -38,9 +38,9 @@ sbx_xcvr::cbx::~cbx(void){
     /* NOP */
 }
 
-void sbx_xcvr::cbx::write_lo_regs(dboard_iface::unit_t unit, const std::vector<boost::uint32_t> &regs)
+void sbx_xcvr::cbx::write_lo_regs(dboard_iface::unit_t unit, const std::vector<uint32_t> &regs)
 {
-    BOOST_FOREACH(boost::uint32_t reg, regs)
+    BOOST_FOREACH(uint32_t reg, regs)
     {
         self_base->get_iface()->write_spi(unit, spi_config_t::EDGE_RISE, reg, 32);
     }
