@@ -48,6 +48,7 @@
 
 using namespace uhd;
 using namespace uhd::usrp;
+using namespace uhd::usrp::gpio_atr;
 using namespace uhd::transport;
 namespace fs = boost::filesystem;
 namespace asio = boost::asio;
@@ -103,7 +104,7 @@ static std::vector<std::string> discover_ip_addrs(
 
     // loop for replies until timeout
     while (true) {
-        boost::uint8_t buff[sizeof(i2c_transaction_t)] = {};
+        uint8_t buff[sizeof(i2c_transaction_t)] = {};
         const size_t nbytes = udp_bcast_xport->recv(boost::asio::buffer(buff), 0.050);
         if (nbytes == 0)
             break; //No more responses
@@ -272,7 +273,7 @@ static device::sptr e300_make(const device_addr_t &device_addr)
 void get_e3x0_fpga_images(const uhd::device_addr_t &device_addr,
                           std::string &fpga_image,
                           std::string &idle_image){
-    const boost::uint16_t pid = boost::lexical_cast<boost::uint16_t>(
+    const uint16_t pid = boost::lexical_cast<uint16_t>(
             device_addr["product"]);
 
     //extract the FPGA path for the e300
@@ -404,7 +405,7 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     _codec_mgr = ad936x_manager::make(_codec_ctrl, fpga::NUM_RADIOS);
 
 #ifdef E300_GPSD
-    UHD_MSG(status) << "Detecting internal GPSDO " << std::flush;
+    UHD_MSG(status) << "Detecting internal GPS " << std::flush;
     try {
         if (_xport_path == AXI)
             _gps = gpsd_iface::make("localhost", 2947);
@@ -470,14 +471,14 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     BOOST_FOREACH(const std::string &name, _sensor_manager->get_sensors())
     {
         _tree->create<sensor_value_t>(mb_path / "sensors" / name)
-            .publish(boost::bind(&e300_sensor_manager::get_sensor, _sensor_manager, name));
+            .set_publisher(boost::bind(&e300_sensor_manager::get_sensor, _sensor_manager, name));
     }
 #ifdef E300_GPSD
     if (_gps) {
         BOOST_FOREACH(const std::string &name, _gps->get_sensors())
         {
             _tree->create<sensor_value_t>(mb_path / "sensors" / name)
-                .publish(boost::bind(&gpsd_iface::get_sensor, _gps, name));
+                .set_publisher(boost::bind(&gpsd_iface::get_sensor, _gps, name));
         }
     }
 #endif
@@ -487,7 +488,7 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     ////////////////////////////////////////////////////////////////////
     _tree->create<mboard_eeprom_t>(mb_path / "eeprom")
         .set(_eeprom_manager->get_mb_eeprom())  // set first...
-        .subscribe(boost::bind(
+        .add_coerced_subscriber(boost::bind(
             &e300_eeprom_manager::write_mb_eeprom,
             _eeprom_manager, _1));
 
@@ -495,9 +496,9 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     // clocking
     ////////////////////////////////////////////////////////////////////
     _tree->create<double>(mb_path / "tick_rate")
-        .coerce(boost::bind(&e300_impl::_set_tick_rate, this, _1))
-        .publish(boost::bind(&e300_impl::_get_tick_rate, this))
-        .subscribe(boost::bind(&e300_impl::_update_tick_rate, this, _1));
+        .set_coercer(boost::bind(&e300_impl::_set_tick_rate, this, _1))
+        .set_publisher(boost::bind(&e300_impl::_get_tick_rate, this))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_tick_rate, this, _1));
 
     //default some chains on -- needed for setup purposes
     _codec_ctrl->set_active_chains(true, false, true, false);
@@ -509,42 +510,47 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     for(size_t instance = 0; instance < fpga::NUM_RADIOS; instance++)
         this->_setup_radio(instance);
 
-    // Radio 0 loopback through AD9361
-    _codec_mgr->loopback_self_test(_radio_perifs[0].ctrl, radio::sr_addr(radio::CODEC_IDLE), radio::RB64_CODEC_READBACK);
-    // Radio 1 loopback through AD9361
-    _codec_mgr->loopback_self_test(_radio_perifs[1].ctrl, radio::sr_addr(radio::CODEC_IDLE), radio::RB64_CODEC_READBACK);
-
+    //now test each radio module's connection to the codec interface
+    BOOST_FOREACH(radio_perifs_t &perif, _radio_perifs)
+    {
+        _codec_mgr->loopback_self_test(
+            boost::bind(
+                &radio_ctrl_core_3000::poke32, perif.ctrl, radio::sr_addr(radio::CODEC_IDLE), _1
+            ),
+            boost::bind(&radio_ctrl_core_3000::peek64, perif.ctrl, radio::RB64_CODEC_READBACK)
+        );
+    }
     ////////////////////////////////////////////////////////////////////
     // internal gpios
     ////////////////////////////////////////////////////////////////////
-    gpio_core_200::sptr fp_gpio = gpio_core_200::make(_radio_perifs[0].ctrl, radio::sr_addr(radio::FP_GPIO), radio::RB32_FP_GPIO);
+    gpio_atr_3000::sptr fp_gpio = gpio_atr_3000::make(_radio_perifs[0].ctrl, radio::sr_addr(radio::FP_GPIO), radio::RB32_FP_GPIO);
     BOOST_FOREACH(const gpio_attr_map_t::value_type attr, gpio_attr_map)
     {
-        _tree->create<boost::uint32_t>(mb_path / "gpio" / "INT0" / attr.second)
-            .subscribe(boost::bind(&e300_impl::_set_internal_gpio, this, fp_gpio, attr.first, _1))
+        _tree->create<uint32_t>(mb_path / "gpio" / "INT0" / attr.second)
+            .add_coerced_subscriber(boost::bind(&gpio_atr_3000::set_gpio_attr, fp_gpio, attr.first, _1))
             .set(0);
     }
-    _tree->create<boost::uint8_t>(mb_path / "gpio" / "INT0" / "READBACK")
-        .publish(boost::bind(&e300_impl::_get_internal_gpio, this, fp_gpio));
+    _tree->create<uint8_t>(mb_path / "gpio" / "INT0" / "READBACK")
+        .set_publisher(boost::bind(&gpio_atr_3000::read_gpio, fp_gpio));
 
 
     ////////////////////////////////////////////////////////////////////
     // register the time keepers - only one can be the highlander
     ////////////////////////////////////////////////////////////////////
     _tree->create<time_spec_t>(mb_path / "time" / "now")
-        .publish(boost::bind(&time_core_3000::get_time_now, _radio_perifs[0].time64))
-        .subscribe(boost::bind(&e300_impl::_set_time, this, _1))
+        .set_publisher(boost::bind(&time_core_3000::get_time_now, _radio_perifs[0].time64))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_set_time, this, _1))
         .set(0.0);
     //re-sync the times when the tick rate changes
     _tree->access<double>(mb_path / "tick_rate")
-        .subscribe(boost::bind(&e300_impl::_sync_times, this));
+        .add_coerced_subscriber(boost::bind(&e300_impl::_sync_times, this));
     _tree->create<time_spec_t>(mb_path / "time" / "pps")
-        .publish(boost::bind(&time_core_3000::get_time_last_pps, _radio_perifs[0].time64))
-        .subscribe(boost::bind(&time_core_3000::set_time_next_pps, _radio_perifs[0].time64, _1))
-        .subscribe(boost::bind(&time_core_3000::set_time_next_pps, _radio_perifs[1].time64, _1));
+        .set_publisher(boost::bind(&time_core_3000::get_time_last_pps, _radio_perifs[0].time64))
+        .add_coerced_subscriber(boost::bind(&time_core_3000::set_time_next_pps, _radio_perifs[0].time64, _1))
+        .add_coerced_subscriber(boost::bind(&time_core_3000::set_time_next_pps, _radio_perifs[1].time64, _1));
     //setup time source props
     _tree->create<std::string>(mb_path / "time_source" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_time_source, this, _1))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_time_source, this, _1))
         .set(e300::DEFAULT_TIME_SRC);
 #ifdef E300_GPSD
     static const std::vector<std::string> time_sources = boost::assign::list_of("none")("internal")("external")("gpsdo");
@@ -554,7 +560,7 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     _tree->create<std::vector<std::string> >(mb_path / "time_source" / "options").set(time_sources);
     //setup reference source props
     _tree->create<std::string>(mb_path / "clock_source" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_clock_source, this, _1))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_clock_source, this, _1))
         .set(e300::DEFAULT_CLOCK_SRC);
     static const std::vector<std::string> clock_sources = boost::assign::list_of("internal"); //external,gpsdo not supported
     _tree->create<std::vector<std::string> >(mb_path / "clock_source" / "options").set(clock_sources);
@@ -565,13 +571,13 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     dboard_eeprom_t db_eeprom;
     _tree->create<dboard_eeprom_t>(mb_path / "dboards" / "A" / "rx_eeprom")
         .set(_eeprom_manager->get_db_eeprom())
-        .subscribe(boost::bind(
+        .add_coerced_subscriber(boost::bind(
             &e300_eeprom_manager::write_db_eeprom,
             _eeprom_manager, _1));
 
     _tree->create<dboard_eeprom_t>(mb_path / "dboards" / "A" / "tx_eeprom")
         .set(_eeprom_manager->get_db_eeprom())
-        .subscribe(boost::bind(
+        .add_coerced_subscriber(boost::bind(
             &e300_eeprom_manager::write_db_eeprom,
             _eeprom_manager, _1));
 
@@ -604,10 +610,10 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
 
     _tree->create<subdev_spec_t>(mb_path / "rx_subdev_spec")
         .set(subdev_spec_t())
-        .subscribe(boost::bind(&e300_impl::_update_subdev_spec, this, "rx", _1));
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_subdev_spec, this, "rx", _1));
     _tree->create<subdev_spec_t>(mb_path / "tx_subdev_spec")
         .set(subdev_spec_t())
-        .subscribe(boost::bind(&e300_impl::_update_subdev_spec, this, "tx", _1));
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_subdev_spec, this, "tx", _1));
 
     ////////////////////////////////////////////////////////////////////
     // do some post-init tasks
@@ -631,40 +637,9 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     _tree->access<subdev_spec_t>(mb_path / "tx_subdev_spec").set(tx_spec);
 }
 
-boost::uint8_t e300_impl::_get_internal_gpio(gpio_core_200::sptr gpio)
-{
-    return boost::uint32_t(gpio->read_gpio(dboard_iface::UNIT_RX));
-}
-
-void e300_impl::_set_internal_gpio(
-    gpio_core_200::sptr gpio,
-    const gpio_attr_t attr,
-    const boost::uint32_t value)
-{
-    switch (attr)
-    {
-    case GPIO_CTRL:
-        return gpio->set_pin_ctrl(dboard_iface::UNIT_RX, value);
-    case GPIO_DDR:
-        return gpio->set_gpio_ddr(dboard_iface::UNIT_RX, value);
-    case GPIO_OUT:
-        return gpio->set_gpio_out(dboard_iface::UNIT_RX, value);
-    case GPIO_ATR_0X:
-        return gpio->set_atr_reg(dboard_iface::UNIT_RX, dboard_iface::ATR_REG_IDLE, value);
-    case GPIO_ATR_RX:
-        return gpio->set_atr_reg(dboard_iface::UNIT_RX, dboard_iface::ATR_REG_RX_ONLY, value);
-    case GPIO_ATR_TX:
-        return gpio->set_atr_reg(dboard_iface::UNIT_RX, dboard_iface::ATR_REG_TX_ONLY, value);
-    case GPIO_ATR_XX:
-        return gpio->set_atr_reg(dboard_iface::UNIT_RX, dboard_iface::ATR_REG_FULL_DUPLEX, value);
-    default:
-        UHD_THROW_INVALID_CODE_PATH();
-    }
-}
-
 uhd::sensor_value_t e300_impl::_get_fe_pll_lock(const bool is_tx)
 {
-    const boost::uint32_t st =
+    const uint32_t st =
         _global_regs->peek32(global_regs::RB32_CORE_PLL);
     const bool locked = is_tx ? ((st & 0x1) > 0) : ((st & 0x2) > 0);
     return sensor_value_t("LO", locked, "locked", "unlocked");
@@ -737,16 +712,16 @@ void e300_impl::_register_loopback_self_test(wb_iface::sptr iface)
     for (size_t i = 0; i < 100; i++)
     {
         boost::hash_combine(hash, i);
-        iface->poke32(radio::sr_addr(radio::TEST), boost::uint32_t(hash));
-        test_fail = iface->peek32(radio::RB32_TEST) != boost::uint32_t(hash);
+        iface->poke32(radio::sr_addr(radio::TEST), uint32_t(hash));
+        test_fail = iface->peek32(radio::RB32_TEST) != uint32_t(hash);
         if (test_fail) break; //exit loop on any failure
     }
     UHD_MSG(status) << ((test_fail)? " fail" : "pass") << std::endl;
 }
 
-boost::uint32_t e300_impl::_get_version(compat_t which)
+uint32_t e300_impl::_get_version(compat_t which)
 {
-    const boost::uint16_t compat_num
+    const uint16_t compat_num
         = _global_regs->peek32(global_regs::RB32_CORE_COMPAT);
 
     switch(which) {
@@ -761,18 +736,18 @@ boost::uint32_t e300_impl::_get_version(compat_t which)
 
 std::string e300_impl::_get_version_hash(void)
 {
-    const boost::uint32_t git_hash
+    const uint32_t git_hash
         = _global_regs->peek32(global_regs::RB32_CORE_GITHASH);
     return str(boost::format("%7x%s")
         % (git_hash & 0x0FFFFFFF)
         % ((git_hash & 0xF000000) ? "-dirty" : ""));
 }
 
-boost::uint32_t e300_impl::_allocate_sid(const sid_config_t &config)
+uint32_t e300_impl::_allocate_sid(const sid_config_t &config)
 {
-    const boost::uint32_t stream = (config.dst_prefix | (config.router_dst_there << 2)) & 0xff;
+    const uint32_t stream = (config.dst_prefix | (config.router_dst_there << 2)) & 0xff;
 
-    const boost::uint32_t sid = 0
+    const uint32_t sid = 0
         | (E300_DEVICE_HERE << 24)
         | (_sid_framer << 16)
         | (config.router_addr_there << 8)
@@ -810,7 +785,7 @@ boost::uint32_t e300_impl::_allocate_sid(const sid_config_t &config)
     return sid;
 }
 
-void e300_impl::_setup_dest_mapping(const boost::uint32_t sid, const size_t which_stream)
+void e300_impl::_setup_dest_mapping(const uint32_t sid, const size_t which_stream)
 {
     UHD_LOG << boost::format("Setting up dest map for 0x%lx to be stream %d")
                                      % (sid & 0xff) % which_stream << std::endl;
@@ -850,44 +825,44 @@ void e300_impl::_sync_times()
 }
 
 size_t e300_impl::_get_axi_dma_channel(
-    boost::uint8_t destination,
-    boost::uint8_t prefix)
+    uint8_t destination,
+    uint8_t prefix)
 {
-    static const boost::uint32_t RADIO_GRP_SIZE = 4;
-    static const boost::uint32_t RADIO0_GRP     = 0;
-    static const boost::uint32_t RADIO1_GRP     = 1;
+    static const uint32_t RADIO_GRP_SIZE = 4;
+    static const uint32_t RADIO0_GRP     = 0;
+    static const uint32_t RADIO1_GRP     = 1;
 
-    boost::uint32_t radio_grp = (destination == E300_XB_DST_R0) ? RADIO0_GRP : RADIO1_GRP;
+    uint32_t radio_grp = (destination == E300_XB_DST_R0) ? RADIO0_GRP : RADIO1_GRP;
     return ((radio_grp * RADIO_GRP_SIZE) + prefix);
 }
 
-boost::uint16_t e300_impl::_get_udp_port(
-        boost::uint8_t destination,
-        boost::uint8_t prefix)
+uint16_t e300_impl::_get_udp_port(
+        uint8_t destination,
+        uint8_t prefix)
 {
     if (destination == E300_XB_DST_R0) {
         if (prefix == E300_RADIO_DEST_PREFIX_CTRL)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_CTRL_PORT0);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_CTRL_PORT0);
         else if (prefix == E300_RADIO_DEST_PREFIX_TX)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_TX_PORT0);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_TX_PORT0);
         else if (prefix == E300_RADIO_DEST_PREFIX_RX)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_RX_PORT0);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_RX_PORT0);
     } else if (destination == E300_XB_DST_R1) {
         if (prefix == E300_RADIO_DEST_PREFIX_CTRL)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_CTRL_PORT1);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_CTRL_PORT1);
         else if (prefix == E300_RADIO_DEST_PREFIX_TX)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_TX_PORT1);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_TX_PORT1);
         else if (prefix == E300_RADIO_DEST_PREFIX_RX)
-            return boost::lexical_cast<boost::uint16_t>(E300_SERVER_RX_PORT1);
+            return boost::lexical_cast<uint16_t>(E300_SERVER_RX_PORT1);
     }
     throw uhd::value_error(str(boost::format("No UDP port defined for combination: %u %u") % destination % prefix));
 }
 
 e300_impl::both_xports_t e300_impl::_make_transport(
-    const boost::uint8_t &destination,
-    const boost::uint8_t &prefix,
+    const uint8_t &destination,
+    const uint8_t &prefix,
     const uhd::transport::zero_copy_xport_params &params,
-    boost::uint32_t &sid)
+    uint32_t &sid)
 {
     both_xports_t xports;
 
@@ -915,7 +890,7 @@ e300_impl::both_xports_t e300_impl::_make_transport(
     } else if (_xport_path == ETH) {
         // lookup which udp port we need
         // to use to create our transport
-        const boost::uint16_t port = _get_udp_port(
+        const uint16_t port = _get_udp_port(
             destination,
             prefix);
 
@@ -975,7 +950,7 @@ void e300_impl::_setup_radio(const size_t dspno)
     ////////////////////////////////////////////////////////////////////
 
     // make a transport, grab a sid
-    boost::uint32_t ctrl_sid;
+    uint32_t ctrl_sid;
     both_xports_t ctrl_xports = _make_transport(
        dspno ? E300_XB_DST_R1 : E300_XB_DST_R0,
        E300_RADIO_DEST_PREFIX_CTRL,
@@ -1001,7 +976,8 @@ void e300_impl::_setup_radio(const size_t dspno)
     ////////////////////////////////////////////////////////////////////
     // Set up peripherals
     ////////////////////////////////////////////////////////////////////
-    perif.atr = gpio_core_200_32wo::make(perif.ctrl, radio::sr_addr(radio::GPIO));
+    perif.atr = gpio_atr_3000::make_write_only(perif.ctrl, radio::sr_addr(radio::GPIO));
+    perif.atr->set_atr_mode(MODE_ATR, 0xFFFFFFFF);
     perif.rx_fe = rx_frontend_core_200::make(perif.ctrl, radio::sr_addr(radio::RX_FRONT));
     perif.rx_fe->set_dc_offset(rx_frontend_core_200::DEFAULT_DC_OFFSET_VALUE);
     perif.rx_fe->set_dc_offset_auto(rx_frontend_core_200::DEFAULT_DC_OFFSET_ENABLE);
@@ -1036,26 +1012,25 @@ void e300_impl::_setup_radio(const size_t dspno)
     // connect rx dsp control objects
     ////////////////////////////////////////////////////////////////////
     _tree->access<double>(mb_path / "tick_rate")
-        .subscribe(boost::bind(&rx_vita_core_3000::set_tick_rate, perif.framer, _1))
-        .subscribe(boost::bind(&rx_dsp_core_3000::set_tick_rate, perif.ddc, _1));
+        .add_coerced_subscriber(boost::bind(&rx_vita_core_3000::set_tick_rate, perif.framer, _1))
+        .add_coerced_subscriber(boost::bind(&rx_dsp_core_3000::set_tick_rate, perif.ddc, _1));
     const fs_path rx_dsp_path = mb_path / "rx_dsps" / str(boost::format("%u") % dspno);
     perif.ddc->populate_subtree(_tree->subtree(rx_dsp_path));
     _tree->access<double>(rx_dsp_path / "rate" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_rx_samp_rate, this, dspno, _1))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_rx_samp_rate, this, dspno, _1))
     ;
     _tree->create<stream_cmd_t>(rx_dsp_path / "stream_cmd")
-        .subscribe(boost::bind(&rx_vita_core_3000::issue_stream_command, perif.framer, _1));
+        .add_coerced_subscriber(boost::bind(&rx_vita_core_3000::issue_stream_command, perif.framer, _1));
 
     ////////////////////////////////////////////////////////////////////
     // create tx dsp control objects
     ////////////////////////////////////////////////////////////////////
     _tree->access<double>(mb_path / "tick_rate")
-        .subscribe(boost::bind(&tx_vita_core_3000::set_tick_rate, perif.deframer, _1))
-        .subscribe(boost::bind(&tx_dsp_core_3000::set_tick_rate, perif.duc, _1));
+        .add_coerced_subscriber(boost::bind(&tx_dsp_core_3000::set_tick_rate, perif.duc, _1));
     const fs_path tx_dsp_path = mb_path / "tx_dsps" / str(boost::format("%u") % dspno);
     perif.duc->populate_subtree(_tree->subtree(tx_dsp_path));
     _tree->access<double>(tx_dsp_path / "rate" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_tx_samp_rate, this, dspno, _1))
+        .add_coerced_subscriber(boost::bind(&e300_impl::_update_tx_samp_rate, this, dspno, _1))
     ;
 
     ////////////////////////////////////////////////////////////////////
@@ -1075,10 +1050,10 @@ void e300_impl::_setup_radio(const size_t dspno)
 
         // This will connect all the e300_impl-specific items
         _tree->create<sensor_value_t>(rf_fe_path / "sensors" / "lo_locked")
-            .publish(boost::bind(&e300_impl::_get_fe_pll_lock, this, dir == TX_DIRECTION))
+            .set_publisher(boost::bind(&e300_impl::_get_fe_pll_lock, this, dir == TX_DIRECTION))
         ;
         _tree->access<double>(rf_fe_path / "freq" / "value")
-            .subscribe(boost::bind(&e300_impl::_update_fe_lo_freq, this, key, _1))
+            .add_coerced_subscriber(boost::bind(&e300_impl::_update_fe_lo_freq, this, key, _1))
         ;
 
         // Antenna Setup
@@ -1086,7 +1061,7 @@ void e300_impl::_setup_radio(const size_t dspno)
             static const std::vector<std::string> ants = boost::assign::list_of("TX/RX")("RX2");
             _tree->create<std::vector<std::string> >(rf_fe_path / "antenna" / "options").set(ants);
             _tree->create<std::string>(rf_fe_path / "antenna" / "value")
-                .subscribe(boost::bind(&e300_impl::_update_antenna_sel, this, dspno, _1))
+                .add_coerced_subscriber(boost::bind(&e300_impl::_update_antenna_sel, this, dspno, _1))
                 .set("RX2");
         }
         else if (dir == TX_DIRECTION) {
@@ -1127,7 +1102,7 @@ void e300_impl::_update_enables(void)
 
 void e300_impl::_update_gpio_state(void)
 {
-    boost::uint32_t misc_reg = 0
+    uint32_t misc_reg = 0
         | (_misc.pps_sel      << gpio_t::PPS_SEL)
         | (_misc.mimo         << gpio_t::MIMO)
         | (_misc.codec_arst   << gpio_t::CODEC_ARST)
@@ -1315,11 +1290,11 @@ void e300_impl::_update_atrs(void)
         if (enb_tx)
             fd_reg |= tx_enables | xx_leds;
 
-        gpio_core_200_32wo::sptr atr = _radio_perifs[instance].atr;
-        atr->set_atr_reg(dboard_iface::ATR_REG_IDLE, oo_reg);
-        atr->set_atr_reg(dboard_iface::ATR_REG_RX_ONLY, rx_reg);
-        atr->set_atr_reg(dboard_iface::ATR_REG_TX_ONLY, tx_reg);
-        atr->set_atr_reg(dboard_iface::ATR_REG_FULL_DUPLEX, fd_reg);
+        gpio_atr_3000::sptr atr = _radio_perifs[instance].atr;
+        atr->set_atr_reg(ATR_REG_IDLE, oo_reg);
+        atr->set_atr_reg(ATR_REG_RX_ONLY, rx_reg);
+        atr->set_atr_reg(ATR_REG_TX_ONLY, tx_reg);
+        atr->set_atr_reg(ATR_REG_FULL_DUPLEX, fd_reg);
     }
 }
 
