@@ -18,7 +18,7 @@
 #ifndef INCLUDED_GPSD_IFACE_HPP
 #define INCLUDED_GPSD_IFACE_HPP
 
-#include <boost/cstdint.hpp>
+#include <stdint.h>
 #include <boost/shared_ptr.hpp>
 
 #include <uhd/usrp/gps_ctrl.hpp>
@@ -28,7 +28,7 @@ namespace uhd { namespace usrp {
 class gpsd_iface : public virtual uhd::gps_ctrl {
 public:
     typedef boost::shared_ptr<gpsd_iface> sptr;
-    static sptr make(const std::string &addr, boost::uint16_t port);
+    static sptr make(const std::string &addr, uint16_t port);
 };
 
 }};
