@@ -36,10 +36,8 @@ using namespace uhd;
 using namespace uhd::usrp;
 using namespace uhd::transport;
 
-const boost::uint16_t USRP1_VENDOR_ID  = 0xfffe;
-const boost::uint16_t USRP1_PRODUCT_ID = 0x0002;
-const boost::uint16_t FX2_VENDOR_ID    = 0x04b4;
-const boost::uint16_t FX2_PRODUCT_ID   = 0x8613;
+const uint16_t USRP1_VENDOR_ID  = 0xfffe;
+const uint16_t USRP1_PRODUCT_ID = 0x0002;
 static const boost::posix_time::milliseconds REENUMERATION_TIMEOUT_MS(3000);
 
 const std::vector<usrp1_impl::dboard_slot_t> usrp1_impl::_dboard_slots = boost::assign::list_of
@@ -60,11 +58,11 @@ static device_addrs_t usrp1_find(const device_addr_t &hint)
     //since an address and resource is intended for a different, non-USB, device.
     if (hint.has_key("addr") || hint.has_key("resource")) return usrp1_addrs;
 
-    boost::uint16_t vid, pid;
+    uint16_t vid, pid;
 
     if(hint.has_key("vid") && hint.has_key("pid") && hint.has_key("type") && hint["type"] == "usrp1") {
-        vid = uhd::cast::hexstr_cast<boost::uint16_t>(hint.get("vid"));
-        pid = uhd::cast::hexstr_cast<boost::uint16_t>(hint.get("pid"));
+        vid = uhd::cast::hexstr_cast<uint16_t>(hint.get("vid"));
+        pid = uhd::cast::hexstr_cast<uint16_t>(hint.get("pid"));
     } else {
         vid = USRP1_VENDOR_ID;
         pid = USRP1_PRODUCT_ID;
@@ -209,13 +207,13 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     const fs_path mb_path = "/mboards/0";
     _tree->create<std::string>(mb_path / "name").set("USRP1");
     _tree->create<std::string>(mb_path / "load_eeprom")
-        .subscribe(boost::bind(&fx2_ctrl::usrp_load_eeprom, _fx2_ctrl, _1));
+        .add_coerced_subscriber(boost::bind(&fx2_ctrl::usrp_load_eeprom, _fx2_ctrl, _1));
 
     ////////////////////////////////////////////////////////////////////
     // create user-defined control objects
     ////////////////////////////////////////////////////////////////////
-    _tree->create<std::pair<boost::uint8_t, boost::uint32_t> >(mb_path / "user" / "regs")
-        .subscribe(boost::bind(&usrp1_impl::set_reg, this, _1));
+    _tree->create<std::pair<uint8_t, uint32_t> >(mb_path / "user" / "regs")
+        .add_coerced_subscriber(boost::bind(&usrp1_impl::set_reg, this, _1));
 
     ////////////////////////////////////////////////////////////////////
     // setup the mboard eeprom
@@ -223,7 +221,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     const mboard_eeprom_t mb_eeprom(*_fx2_ctrl, USRP1_EEPROM_MAP_KEY);
     _tree->create<mboard_eeprom_t>(mb_path / "eeprom")
         .set(mb_eeprom)
-        .subscribe(boost::bind(&usrp1_impl::set_mb_eeprom, this, _1));
+        .add_coerced_subscriber(boost::bind(&usrp1_impl::set_mb_eeprom, this, _1));
 
     ////////////////////////////////////////////////////////////////////
     // create clock control objects
@@ -247,7 +245,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     }
     UHD_MSG(status) << boost::format("Using FPGA clock rate of %fMHz...") % (_master_clock_rate/1e6) << std::endl;
     _tree->create<double>(mb_path / "tick_rate")
-        .subscribe(boost::bind(&usrp1_impl::update_tick_rate, this, _1))
+        .add_coerced_subscriber(boost::bind(&usrp1_impl::update_tick_rate, this, _1))
         .set(_master_clock_rate);
 
     ////////////////////////////////////////////////////////////////////
@@ -260,13 +258,13 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
         _tree->create<std::string>(rx_codec_path / "name").set("ad9522");
         _tree->create<meta_range_t>(rx_codec_path / "gains/pga/range").set(usrp1_codec_ctrl::rx_pga_gain_range);
         _tree->create<double>(rx_codec_path / "gains/pga/value")
-            .coerce(boost::bind(&usrp1_impl::update_rx_codec_gain, this, db, _1))
+            .set_coercer(boost::bind(&usrp1_impl::update_rx_codec_gain, this, db, _1))
             .set(0.0);
         _tree->create<std::string>(tx_codec_path / "name").set("ad9522");
         _tree->create<meta_range_t>(tx_codec_path / "gains/pga/range").set(usrp1_codec_ctrl::tx_pga_gain_range);
         _tree->create<double>(tx_codec_path / "gains/pga/value")
-            .subscribe(boost::bind(&usrp1_codec_ctrl::set_tx_pga_gain, _dbc[db].codec, _1))
-            .publish(boost::bind(&usrp1_codec_ctrl::get_tx_pga_gain, _dbc[db].codec))
+            .add_coerced_subscriber(boost::bind(&usrp1_codec_ctrl::set_tx_pga_gain, _dbc[db].codec, _1))
+            .set_publisher(boost::bind(&usrp1_codec_ctrl::get_tx_pga_gain, _dbc[db].codec))
             .set(0.0);
     }
 
@@ -281,18 +279,18 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     ////////////////////////////////////////////////////////////////////
     _tree->create<subdev_spec_t>(mb_path / "rx_subdev_spec")
         .set(subdev_spec_t())
-        .subscribe(boost::bind(&usrp1_impl::update_rx_subdev_spec, this, _1));
+        .add_coerced_subscriber(boost::bind(&usrp1_impl::update_rx_subdev_spec, this, _1));
     _tree->create<subdev_spec_t>(mb_path / "tx_subdev_spec")
         .set(subdev_spec_t())
-        .subscribe(boost::bind(&usrp1_impl::update_tx_subdev_spec, this, _1));
+        .add_coerced_subscriber(boost::bind(&usrp1_impl::update_tx_subdev_spec, this, _1));
 
     BOOST_FOREACH(const std::string &db, _dbc.keys()){
         const fs_path rx_fe_path = mb_path / "rx_frontends" / db;
         _tree->create<std::complex<double> >(rx_fe_path / "dc_offset" / "value")
-            .coerce(boost::bind(&usrp1_impl::set_rx_dc_offset, this, db, _1))
+            .set_coercer(boost::bind(&usrp1_impl::set_rx_dc_offset, this, db, _1))
             .set(std::complex<double>(0.0, 0.0));
         _tree->create<bool>(rx_fe_path / "dc_offset" / "enable")
-            .subscribe(boost::bind(&usrp1_impl::set_enb_rx_dc_offset, this, db, _1))
+            .add_coerced_subscriber(boost::bind(&usrp1_impl::set_enb_rx_dc_offset, this, db, _1))
             .set(true);
     }
 
@@ -303,19 +301,19 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     for (size_t dspno = 0; dspno < get_num_ddcs(); dspno++){
         fs_path rx_dsp_path = mb_path / str(boost::format("rx_dsps/%u") % dspno);
         _tree->create<meta_range_t>(rx_dsp_path / "rate/range")
-            .publish(boost::bind(&usrp1_impl::get_rx_dsp_host_rates, this));
+            .set_publisher(boost::bind(&usrp1_impl::get_rx_dsp_host_rates, this));
         _tree->create<double>(rx_dsp_path / "rate/value")
             .set(1e6) //some default rate
-            .coerce(boost::bind(&usrp1_impl::update_rx_samp_rate, this, dspno, _1));
+            .set_coercer(boost::bind(&usrp1_impl::update_rx_samp_rate, this, dspno, _1));
         _tree->create<double>(rx_dsp_path / "freq/value")
-            .coerce(boost::bind(&usrp1_impl::update_rx_dsp_freq, this, dspno, _1));
+            .set_coercer(boost::bind(&usrp1_impl::update_rx_dsp_freq, this, dspno, _1));
         _tree->create<meta_range_t>(rx_dsp_path / "freq/range")
-            .publish(boost::bind(&usrp1_impl::get_rx_dsp_freq_range, this));
+            .set_publisher(boost::bind(&usrp1_impl::get_rx_dsp_freq_range, this));
         _tree->create<stream_cmd_t>(rx_dsp_path / "stream_cmd");
         if (dspno == 0){
-            //only subscribe the callback for dspno 0 since it will stream all dsps
+            //only add_coerced_subscriber the callback for dspno 0 since it will stream all dsps
             _tree->access<stream_cmd_t>(rx_dsp_path / "stream_cmd")
-                .subscribe(boost::bind(&soft_time_ctrl::issue_stream_cmd, _soft_time_ctrl, _1));
+                .add_coerced_subscriber(boost::bind(&soft_time_ctrl::issue_stream_cmd, _soft_time_ctrl, _1));
         }
     }
 
@@ -326,22 +324,22 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     for (size_t dspno = 0; dspno < get_num_ducs(); dspno++){
         fs_path tx_dsp_path = mb_path / str(boost::format("tx_dsps/%u") % dspno);
         _tree->create<meta_range_t>(tx_dsp_path / "rate/range")
-            .publish(boost::bind(&usrp1_impl::get_tx_dsp_host_rates, this));
+            .set_publisher(boost::bind(&usrp1_impl::get_tx_dsp_host_rates, this));
         _tree->create<double>(tx_dsp_path / "rate/value")
             .set(1e6) //some default rate
-            .coerce(boost::bind(&usrp1_impl::update_tx_samp_rate, this, dspno, _1));
+            .set_coercer(boost::bind(&usrp1_impl::update_tx_samp_rate, this, dspno, _1));
         _tree->create<double>(tx_dsp_path / "freq/value")
-            .coerce(boost::bind(&usrp1_impl::update_tx_dsp_freq, this, dspno, _1));
+            .set_coercer(boost::bind(&usrp1_impl::update_tx_dsp_freq, this, dspno, _1));
         _tree->create<meta_range_t>(tx_dsp_path / "freq/range")
-            .publish(boost::bind(&usrp1_impl::get_tx_dsp_freq_range, this));
+            .set_publisher(boost::bind(&usrp1_impl::get_tx_dsp_freq_range, this));
     }
 
     ////////////////////////////////////////////////////////////////////
     // create time control objects
     ////////////////////////////////////////////////////////////////////
     _tree->create<time_spec_t>(mb_path / "time/now")
-        .publish(boost::bind(&soft_time_ctrl::get_time, _soft_time_ctrl))
-        .subscribe(boost::bind(&soft_time_ctrl::set_time, _soft_time_ctrl, _1));
+        .set_publisher(boost::bind(&soft_time_ctrl::get_time, _soft_time_ctrl))
+        .add_coerced_subscriber(boost::bind(&soft_time_ctrl::set_time, _soft_time_ctrl, _1));
 
     _tree->create<std::vector<std::string> >(mb_path / "clock_source/options").set(std::vector<std::string>(1, "internal"));
     _tree->create<std::vector<std::string> >(mb_path / "time_source/options").set(std::vector<std::string>(1, "none"));
@@ -365,24 +363,23 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
         //create the properties and register subscribers
         _tree->create<dboard_eeprom_t>(mb_path / "dboards" / db/ "rx_eeprom")
             .set(rx_db_eeprom)
-            .subscribe(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "rx", _1));
+            .add_coerced_subscriber(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "rx", _1));
         _tree->create<dboard_eeprom_t>(mb_path / "dboards" / db/ "tx_eeprom")
             .set(tx_db_eeprom)
-            .subscribe(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "tx", _1));
+            .add_coerced_subscriber(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "tx", _1));
         _tree->create<dboard_eeprom_t>(mb_path / "dboards" / db/ "gdb_eeprom")
             .set(gdb_eeprom)
-            .subscribe(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "gdb", _1));
+            .add_coerced_subscriber(boost::bind(&usrp1_impl::set_db_eeprom, this, db, "gdb", _1));
 
         //create a new dboard interface and manager
-        _dbc[db].dboard_iface = make_dboard_iface(
+        dboard_iface::sptr dboard_iface = make_dboard_iface(
             _iface, _dbc[db].codec,
             (db == "A")? DBOARD_SLOT_A : DBOARD_SLOT_B,
             _master_clock_rate, rx_db_eeprom.id
         );
-        _tree->create<dboard_iface::sptr>(mb_path / "dboards" / db/ "iface").set(_dbc[db].dboard_iface);
         _dbc[db].dboard_manager = dboard_manager::make(
             rx_db_eeprom.id, tx_db_eeprom.id, gdb_eeprom.id,
-            _dbc[db].dboard_iface, _tree->subtree(mb_path / "dboards" / db)
+            dboard_iface, _tree->subtree(mb_path / "dboards" / db)
         );
 
         //init the subdev specs if we have a dboard (wont leave this loop empty)
@@ -433,22 +430,22 @@ usrp1_impl::~usrp1_impl(void){
  * +-----------------------------------------------+-+-----+-+-----+
  */
 size_t usrp1_impl::get_num_ddcs(void){
-    boost::uint32_t regval = _iface->peek32(FR_RB_CAPS);
+    uint32_t regval = _iface->peek32(FR_RB_CAPS);
     return (regval >> 0) & 0x0007;
 }
 
 size_t usrp1_impl::get_num_ducs(void){
-    boost::uint32_t regval = _iface->peek32(FR_RB_CAPS);
+    uint32_t regval = _iface->peek32(FR_RB_CAPS);
     return (regval >> 4) & 0x0007;
 }
 
 bool usrp1_impl::has_rx_halfband(void){
-    boost::uint32_t regval = _iface->peek32(FR_RB_CAPS);
+    uint32_t regval = _iface->peek32(FR_RB_CAPS);
     return (regval >> 3) & 0x0001;
 }
 
 bool usrp1_impl::has_tx_halfband(void){
-    boost::uint32_t regval = _iface->peek32(FR_RB_CAPS);
+    uint32_t regval = _iface->peek32(FR_RB_CAPS);
     return (regval >> 7) & 0x0001;
 }
 
@@ -490,8 +487,8 @@ void usrp1_impl::set_enb_rx_dc_offset(const std::string &db, const bool enb){
 }
 
 std::complex<double> usrp1_impl::set_rx_dc_offset(const std::string &db, const std::complex<double> &offset){
-    const boost::int32_t i_off = boost::math::iround(offset.real() * (1ul << 31));
-    const boost::int32_t q_off = boost::math::iround(offset.imag() * (1ul << 31));
+    const int32_t i_off = boost::math::iround(offset.real() * (1ul << 31));
+    const int32_t q_off = boost::math::iround(offset.imag() * (1ul << 31));
 
     if (db == "A"){
         _iface->poke32(FR_ADC_OFFSET_0, i_off);
@@ -506,7 +503,7 @@ std::complex<double> usrp1_impl::set_rx_dc_offset(const std::string &db, const s
     return std::complex<double>(double(i_off) * (1ul << 31), double(q_off) * (1ul << 31));
 }
 
-void usrp1_impl::set_reg(const std::pair<boost::uint8_t, boost::uint32_t> &reg)
+void usrp1_impl::set_reg(const std::pair<uint8_t, uint32_t> &reg)
 {
     _iface->poke32(reg.first, reg.second);
 }
