@@ -1,5 +1,5 @@
 //
-// Copyright 2010-2012,2015 Ettus Research LLC
+// Copyright 2010-2012,2015,2016 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -54,35 +54,40 @@ public:
     void write_aux_dac(unit_t, aux_dac_t, double);
     double read_aux_adc(unit_t, aux_adc_t);
 
-    void _set_pin_ctrl(unit_t, boost::uint16_t);
-    void _set_atr_reg(unit_t, atr_reg_t, boost::uint16_t);
-    void _set_gpio_ddr(unit_t, boost::uint16_t);
-    void _set_gpio_out(unit_t, boost::uint16_t);
-    void set_gpio_debug(unit_t, int);
-    boost::uint16_t read_gpio(unit_t);
+    void set_pin_ctrl(unit_t unit, uint32_t value, uint32_t mask = 0xffffffff);
+    uint32_t get_pin_ctrl(unit_t unit);
+    void set_atr_reg(unit_t unit, atr_reg_t reg, uint32_t value, uint32_t mask = 0xffffffff);
+    uint32_t get_atr_reg(unit_t unit, atr_reg_t reg);
+    void set_gpio_ddr(unit_t unit, uint32_t value, uint32_t mask = 0xffffffff);
+    uint32_t get_gpio_ddr(unit_t unit);
+    void set_gpio_out(unit_t unit, uint32_t value, uint32_t mask = 0xffffffff);
+    uint32_t get_gpio_out(unit_t unit);
+    uint32_t read_gpio(unit_t unit);
+
     void set_command_time(const uhd::time_spec_t& t);
     uhd::time_spec_t get_command_time(void);
 
-    void write_i2c(boost::uint16_t, const byte_vector_t &);
-    byte_vector_t read_i2c(boost::uint16_t, size_t);
+    void write_i2c(uint16_t, const byte_vector_t &);
+    byte_vector_t read_i2c(uint16_t, size_t);
 
     void set_clock_rate(unit_t, double);
     double get_clock_rate(unit_t);
     std::vector<double> get_clock_rates(unit_t);
     void set_clock_enabled(unit_t, bool);
     double get_codec_rate(unit_t);
+    void set_fe_connection(unit_t unit, const std::string&, const fe_connection_t& fe_conn);
 
     void write_spi(
         unit_t unit,
         const spi_config_t &config,
-        boost::uint32_t data,
+        uint32_t data,
         size_t num_bits
     );
 
-    boost::uint32_t read_write_spi(
+    uint32_t read_write_spi(
         unit_t unit,
         const spi_config_t &config,
-        boost::uint32_t data,
+        uint32_t data,
         size_t num_bits
     );
 
@@ -149,18 +154,22 @@ usrp2_dboard_iface::~usrp2_dboard_iface(void){
  * Clocks
  **********************************************************************/
 void usrp2_dboard_iface::set_clock_rate(unit_t unit, double rate){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     _clock_rates[unit] = rate; //set to shadow
     switch(unit){
     case UNIT_RX: _clock_ctrl->set_rate_rx_dboard_clock(rate); return;
     case UNIT_TX: _clock_ctrl->set_rate_tx_dboard_clock(rate); return;
+    default: UHD_THROW_INVALID_CODE_PATH();
     }
 }
 
 double usrp2_dboard_iface::get_clock_rate(unit_t unit){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     return _clock_rates[unit]; //get from shadow
 }
 
 std::vector<double> usrp2_dboard_iface::get_clock_rates(unit_t unit){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     switch(unit){
     case UNIT_RX: return _clock_ctrl->get_rates_rx_dboard_clock();
     case UNIT_TX: return _clock_ctrl->get_rates_tx_dboard_clock();
@@ -169,42 +178,58 @@ std::vector<double> usrp2_dboard_iface::get_clock_rates(unit_t unit){
 }
 
 void usrp2_dboard_iface::set_clock_enabled(unit_t unit, bool enb){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     switch(unit){
-    case UNIT_RX: _clock_ctrl->enable_rx_dboard_clock(enb); return;
-    case UNIT_TX: _clock_ctrl->enable_tx_dboard_clock(enb); return;
+    case UNIT_RX:   _clock_ctrl->enable_rx_dboard_clock(enb); return;
+    case UNIT_TX:   _clock_ctrl->enable_tx_dboard_clock(enb); return;
+    default: UHD_THROW_INVALID_CODE_PATH();
     }
 }
 
-double usrp2_dboard_iface::get_codec_rate(unit_t){
+double usrp2_dboard_iface::get_codec_rate(unit_t unit){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     return _clock_ctrl->get_master_clock_rate();
 }
+
 /***********************************************************************
  * GPIO
  **********************************************************************/
-void usrp2_dboard_iface::_set_pin_ctrl(unit_t unit, boost::uint16_t value){
-    return _gpio->set_pin_ctrl(unit, value);
+void usrp2_dboard_iface::set_pin_ctrl(unit_t unit, uint32_t value, uint32_t mask){
+    _gpio->set_pin_ctrl(unit, static_cast<uint16_t>(value), static_cast<uint16_t>(mask));
 }
 
-void usrp2_dboard_iface::_set_gpio_ddr(unit_t unit, boost::uint16_t value){
-    return _gpio->set_gpio_ddr(unit, value);
+uint32_t usrp2_dboard_iface::get_pin_ctrl(unit_t unit){
+    return static_cast<uint32_t>(_gpio->get_pin_ctrl(unit));
 }
 
-void usrp2_dboard_iface::_set_gpio_out(unit_t unit, boost::uint16_t value){
-    return _gpio->set_gpio_out(unit, value);
+void usrp2_dboard_iface::set_atr_reg(unit_t unit, atr_reg_t reg, uint32_t value, uint32_t mask){
+    _gpio->set_atr_reg(unit, reg, static_cast<uint16_t>(value), static_cast<uint16_t>(mask));
 }
 
-boost::uint16_t usrp2_dboard_iface::read_gpio(unit_t unit){
+uint32_t usrp2_dboard_iface::get_atr_reg(unit_t unit, atr_reg_t reg){
+    return static_cast<uint32_t>(_gpio->get_atr_reg(unit, reg));
+}
+
+void usrp2_dboard_iface::set_gpio_ddr(unit_t unit, uint32_t value, uint32_t mask){
+    _gpio->set_gpio_ddr(unit, static_cast<uint16_t>(value), static_cast<uint16_t>(mask));
+}
+
+uint32_t usrp2_dboard_iface::get_gpio_ddr(unit_t unit){
+    return static_cast<uint32_t>(_gpio->get_gpio_ddr(unit));
+}
+
+void usrp2_dboard_iface::set_gpio_out(unit_t unit, uint32_t value, uint32_t mask){
+    _gpio->set_gpio_out(unit, static_cast<uint16_t>(value), static_cast<uint16_t>(mask));
+}
+
+uint32_t usrp2_dboard_iface::get_gpio_out(unit_t unit){
+    return static_cast<uint32_t>(_gpio->get_gpio_out(unit));
+}
+
+uint32_t usrp2_dboard_iface::read_gpio(unit_t unit){
     return _gpio->read_gpio(unit);
 }
 
-void usrp2_dboard_iface::_set_atr_reg(unit_t unit, atr_reg_t atr, boost::uint16_t value){
-    return _gpio->set_atr_reg(unit, atr, value);
-}
-
-void usrp2_dboard_iface::set_gpio_debug(unit_t, int){
-    throw uhd::not_implemented_error("no set_gpio_debug implemented");
-}
-
 /***********************************************************************
  * SPI
  **********************************************************************/
@@ -216,29 +241,31 @@ static const uhd::dict<dboard_iface::unit_t, int> unit_to_spi_dev = map_list_of
 void usrp2_dboard_iface::write_spi(
     unit_t unit,
     const spi_config_t &config,
-    boost::uint32_t data,
+    uint32_t data,
     size_t num_bits
 ){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     _spi_iface->write_spi(unit_to_spi_dev[unit], config, data, num_bits);
 }
 
-boost::uint32_t usrp2_dboard_iface::read_write_spi(
+uint32_t usrp2_dboard_iface::read_write_spi(
     unit_t unit,
     const spi_config_t &config,
-    boost::uint32_t data,
+    uint32_t data,
     size_t num_bits
 ){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     return _spi_iface->read_spi(unit_to_spi_dev[unit], config, data, num_bits);
 }
 
 /***********************************************************************
  * I2C
  **********************************************************************/
-void usrp2_dboard_iface::write_i2c(boost::uint16_t addr, const byte_vector_t &bytes){
+void usrp2_dboard_iface::write_i2c(uint16_t addr, const byte_vector_t &bytes){
     return _i2c_iface->write_i2c(addr, bytes);
 }
 
-byte_vector_t usrp2_dboard_iface::read_i2c(boost::uint16_t addr, size_t num_bytes){
+byte_vector_t usrp2_dboard_iface::read_i2c(uint16_t addr, size_t num_bytes){
     return _i2c_iface->read_i2c(addr, num_bytes);
 }
 
@@ -250,6 +277,7 @@ void usrp2_dboard_iface::_write_aux_dac(unit_t unit){
         (UNIT_RX, SPI_SS_RX_DAC)
         (UNIT_TX, SPI_SS_TX_DAC)
     ;
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     _spi_iface->write_spi(
         unit_to_spi_dac[unit], spi_config_t::EDGE_FALL,
         _dac_regs[unit].get_reg(), 24
@@ -257,6 +285,8 @@ void usrp2_dboard_iface::_write_aux_dac(unit_t unit){
 }
 
 void usrp2_dboard_iface::write_aux_dac(unit_t unit, aux_dac_t which, double value){
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+
     _dac_regs[unit].data = boost::math::iround(4095*value/3.3);
     _dac_regs[unit].cmd = ad5623_regs_t::CMD_WR_UP_DAC_CHAN_N;
 
@@ -285,6 +315,8 @@ double usrp2_dboard_iface::read_aux_adc(unit_t unit, aux_adc_t which){
         (UNIT_TX, SPI_SS_TX_ADC)
     ;
 
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+
     //setup spi config args
     spi_config_t config;
     config.mosi_edge = spi_config_t::EDGE_FALL;
@@ -302,7 +334,7 @@ double usrp2_dboard_iface::read_aux_adc(unit_t unit, aux_adc_t which){
         unit_to_spi_adc[unit], config,
         ad7922_regs.get_reg(), 16
     );
-    ad7922_regs.set_reg(boost::uint16_t(_spi_iface->read_spi(
+    ad7922_regs.set_reg(uint16_t(_spi_iface->read_spi(
         unit_to_spi_adc[unit], config,
         ad7922_regs.get_reg(), 16
     )));
@@ -320,3 +352,8 @@ void usrp2_dboard_iface::set_command_time(const uhd::time_spec_t& t)
 {
     _wb_iface->set_time(t);
 }
+
+void usrp2_dboard_iface::set_fe_connection(unit_t, const std::string&, const fe_connection_t&)
+{
+    throw uhd::not_implemented_error("fe connection configuration support not implemented");
+}
