@@ -1,5 +1,5 @@
 //
-// Copyright 2013,2015 Ettus Research LLC
+// Copyright 2013,2015,2016 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -15,85 +15,16 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-#include "x300_impl.hpp"
+#include "x300_dboard_iface.hpp"
 #include "x300_regs.hpp"
-#include <uhd/usrp/dboard_iface.hpp>
 #include <uhd/utils/safe_call.hpp>
 #include <boost/assign/list_of.hpp>
 #include <boost/math/special_functions/round.hpp>
-#include "ad7922_regs.hpp" //aux adc
-#include "ad5623_regs.hpp" //aux dac
 
 using namespace uhd;
 using namespace uhd::usrp;
 using namespace boost::assign;
 
-class x300_dboard_iface : public dboard_iface
-{
-public:
-    x300_dboard_iface(const x300_dboard_iface_config_t &config);
-    ~x300_dboard_iface(void);
-
-    special_props_t get_special_props(void)
-    {
-        special_props_t props;
-        props.soft_clock_divider = false;
-        props.mangle_i2c_addrs = (_config.dboard_slot == 1);
-        return props;
-    }
-
-    void write_aux_dac(unit_t, aux_dac_t, double);
-    double read_aux_adc(unit_t, aux_adc_t);
-
-    void _set_pin_ctrl(unit_t, boost::uint16_t);
-    void _set_atr_reg(unit_t, atr_reg_t, boost::uint16_t);
-    void _set_gpio_ddr(unit_t, boost::uint16_t);
-    void _set_gpio_out(unit_t, boost::uint16_t);
-
-    void set_command_time(const uhd::time_spec_t& t);
-    uhd::time_spec_t get_command_time(void);
-
-    void set_gpio_debug(unit_t, int);
-    boost::uint16_t read_gpio(unit_t);
-
-    void write_i2c(boost::uint16_t, const byte_vector_t &);
-    byte_vector_t read_i2c(boost::uint16_t, size_t);
-
-    void set_clock_rate(unit_t, double);
-    double get_clock_rate(unit_t);
-    std::vector<double> get_clock_rates(unit_t);
-    void set_clock_enabled(unit_t, bool);
-    double get_codec_rate(unit_t);
-
-    void write_spi(
-        unit_t unit,
-        const spi_config_t &config,
-        boost::uint32_t data,
-        size_t num_bits
-    );
-
-    boost::uint32_t read_write_spi(
-        unit_t unit,
-        const spi_config_t &config,
-        boost::uint32_t data,
-        size_t num_bits
-    );
-
-    const x300_dboard_iface_config_t _config;
-    uhd::dict<unit_t, ad5623_regs_t> _dac_regs;
-    uhd::dict<unit_t, double> _clock_rates;
-    void _write_aux_dac(unit_t);
-
-};
-
-/***********************************************************************
- * Make Function
- **********************************************************************/
-dboard_iface::sptr x300_make_dboard_iface(const x300_dboard_iface_config_t &config)
-{
-    return dboard_iface::sptr(new x300_dboard_iface(config));
-}
-
 /***********************************************************************
  * Structors
  **********************************************************************/
@@ -116,27 +47,6 @@ x300_dboard_iface::x300_dboard_iface(const x300_dboard_iface_config_t &config):
 
     this->set_clock_enabled(UNIT_RX, false);
     this->set_clock_enabled(UNIT_TX, false);
-
-
-    //some test code
-    /*
-    {
-
-        this->write_aux_dac(UNIT_TX, AUX_DAC_A, .1);
-        this->write_aux_dac(UNIT_TX, AUX_DAC_B, 1);
-        this->write_aux_dac(UNIT_RX, AUX_DAC_A, 2);
-        this->write_aux_dac(UNIT_RX, AUX_DAC_B, 3);
-        while (1)
-        {
-            UHD_VAR(this->read_aux_adc(UNIT_TX, AUX_ADC_A));
-            UHD_VAR(this->read_aux_adc(UNIT_TX, AUX_ADC_B));
-            UHD_VAR(this->read_aux_adc(UNIT_RX, AUX_ADC_A));
-            UHD_VAR(this->read_aux_adc(UNIT_RX, AUX_ADC_B));
-            sleep(1);
-        }
-    }
-    */
-
 }
 
 x300_dboard_iface::~x300_dboard_iface(void)
@@ -153,6 +63,8 @@ x300_dboard_iface::~x300_dboard_iface(void)
  **********************************************************************/
 void x300_dboard_iface::set_clock_rate(unit_t unit, double rate)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+
     // Just return if the requested rate is already set
     if (std::fabs(_clock_rates[unit] - rate) < std::numeric_limits<double>::epsilon())
         return;
@@ -165,17 +77,21 @@ void x300_dboard_iface::set_clock_rate(unit_t unit, double rate)
         case UNIT_TX:
             _config.clock->set_dboard_rate(_config.which_tx_clk, rate);
             break;
+        default:
+            UHD_THROW_INVALID_CODE_PATH();
     }
     _clock_rates[unit] = rate; //set to shadow
 }
 
 double x300_dboard_iface::get_clock_rate(unit_t unit)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     return _clock_rates[unit]; //get from shadow
 }
 
 std::vector<double> x300_dboard_iface::get_clock_rates(unit_t unit)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     switch(unit)
     {
         case UNIT_RX:
@@ -189,6 +105,7 @@ std::vector<double> x300_dboard_iface::get_clock_rates(unit_t unit)
 
 void x300_dboard_iface::set_clock_enabled(unit_t unit, bool enb)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     switch(unit)
     {
         case UNIT_RX:
@@ -200,77 +117,97 @@ void x300_dboard_iface::set_clock_enabled(unit_t unit, bool enb)
     }
 }
 
-double x300_dboard_iface::get_codec_rate(unit_t)
+double x300_dboard_iface::get_codec_rate(unit_t unit)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     return _config.clock->get_master_clock_rate();
 }
 
 /***********************************************************************
  * GPIO
  **********************************************************************/
-void x300_dboard_iface::_set_pin_ctrl(unit_t unit, boost::uint16_t value)
+void x300_dboard_iface::set_pin_ctrl(unit_t unit, uint32_t value, uint32_t mask)
 {
-    return _config.gpio->set_pin_ctrl(unit, value);
+    _config.gpio->set_pin_ctrl(unit, value, mask);
 }
 
-void x300_dboard_iface::_set_gpio_ddr(unit_t unit, boost::uint16_t value)
+uint32_t x300_dboard_iface::get_pin_ctrl(unit_t unit)
 {
-    return _config.gpio->set_gpio_ddr(unit, value);
+    return _config.gpio->get_pin_ctrl(unit);
 }
 
-void x300_dboard_iface::_set_gpio_out(unit_t unit, boost::uint16_t value)
+void x300_dboard_iface::set_atr_reg(unit_t unit, atr_reg_t reg, uint32_t value, uint32_t mask)
 {
-    return _config.gpio->set_gpio_out(unit, value);
+    _config.gpio->set_atr_reg(unit, reg, value, mask);
 }
 
-boost::uint16_t x300_dboard_iface::read_gpio(unit_t unit)
+uint32_t x300_dboard_iface::get_atr_reg(unit_t unit, atr_reg_t reg)
+{
+    return _config.gpio->get_atr_reg(unit, reg);
+}
+
+void x300_dboard_iface::set_gpio_ddr(unit_t unit, uint32_t value, uint32_t mask)
+{
+    _config.gpio->set_gpio_ddr(unit, value, mask);
+}
+
+uint32_t x300_dboard_iface::get_gpio_ddr(unit_t unit)
+{
+    return _config.gpio->get_gpio_ddr(unit);
+}
+
+void x300_dboard_iface::set_gpio_out(unit_t unit, uint32_t value, uint32_t mask)
+{
+    _config.gpio->set_gpio_out(unit, value, mask);
+}
+
+uint32_t x300_dboard_iface::get_gpio_out(unit_t unit)
+{
+    return _config.gpio->get_gpio_out(unit);
+}
+
+uint32_t x300_dboard_iface::read_gpio(unit_t unit)
 {
     return _config.gpio->read_gpio(unit);
 }
 
-void x300_dboard_iface::_set_atr_reg(unit_t unit, atr_reg_t atr, boost::uint16_t value)
-{
-    return _config.gpio->set_atr_reg(unit, atr, value);
-}
-
-void x300_dboard_iface::set_gpio_debug(unit_t, int)
-{
-    throw uhd::not_implemented_error("no set_gpio_debug implemented");
-}
-
 /***********************************************************************
  * SPI
  **********************************************************************/
-#define toslaveno(unit) \
-    (((unit) == dboard_iface::UNIT_TX)? _config.tx_spi_slaveno : _config.rx_spi_slaveno)
-
 void x300_dboard_iface::write_spi(
     unit_t unit,
     const spi_config_t &config,
-    boost::uint32_t data,
+    uint32_t data,
     size_t num_bits
 ){
-    _config.spi->write_spi(toslaveno(unit), config, data, num_bits);
+    uint32_t slave = 0;
+    if (unit == UNIT_TX) slave |= _config.tx_spi_slaveno;
+    if (unit == UNIT_RX) slave |= _config.rx_spi_slaveno;
+
+    _config.spi->write_spi(int(slave), config, data, num_bits);
 }
 
-boost::uint32_t x300_dboard_iface::read_write_spi(
+uint32_t x300_dboard_iface::read_write_spi(
     unit_t unit,
     const spi_config_t &config,
-    boost::uint32_t data,
+    uint32_t data,
     size_t num_bits
 ){
-    return _config.spi->read_spi(toslaveno(unit), config, data, num_bits);
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+    return _config.spi->read_spi(
+        (unit==dboard_iface::UNIT_TX)?_config.tx_spi_slaveno:_config.rx_spi_slaveno,
+        config, data, num_bits);
 }
 
 /***********************************************************************
  * I2C
  **********************************************************************/
-void x300_dboard_iface::write_i2c(boost::uint16_t addr, const byte_vector_t &bytes)
+void x300_dboard_iface::write_i2c(uint16_t addr, const byte_vector_t &bytes)
 {
     return _config.i2c->write_i2c(addr, bytes);
 }
 
-byte_vector_t x300_dboard_iface::read_i2c(boost::uint16_t addr, size_t num_bytes)
+byte_vector_t x300_dboard_iface::read_i2c(uint16_t addr, size_t num_bytes)
 {
     return _config.i2c->read_i2c(addr, num_bytes);
 }
@@ -284,6 +221,7 @@ void x300_dboard_iface::_write_aux_dac(unit_t unit)
         (UNIT_RX, DB_RX_LSDAC_SEN)
         (UNIT_TX, DB_TX_LSDAC_SEN)
     ;
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
     _config.spi->write_spi(
         unit_to_spi_dac[unit], spi_config_t::EDGE_FALL,
         _dac_regs[unit].get_reg(), 24
@@ -292,6 +230,8 @@ void x300_dboard_iface::_write_aux_dac(unit_t unit)
 
 void x300_dboard_iface::write_aux_dac(unit_t unit, aux_dac_t which, double value)
 {
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+
     _dac_regs[unit].data = boost::math::iround(4095*value/3.3);
     _dac_regs[unit].cmd = ad5623_regs_t::CMD_WR_UP_DAC_CHAN_N;
 
@@ -321,6 +261,8 @@ double x300_dboard_iface::read_aux_adc(unit_t unit, aux_adc_t which)
         (UNIT_TX, DB_TX_LSADC_SEN)
     ;
 
+    if (unit == UNIT_BOTH) throw uhd::runtime_error("UNIT_BOTH not supported.");
+
     //setup spi config args
     spi_config_t config;
     config.mosi_edge = spi_config_t::EDGE_FALL;
@@ -338,7 +280,7 @@ double x300_dboard_iface::read_aux_adc(unit_t unit, aux_adc_t which)
         unit_to_spi_adc[unit], config,
         ad7922_regs.get_reg(), 16
     );
-    ad7922_regs.set_reg(boost::uint16_t(_config.spi->read_spi(
+    ad7922_regs.set_reg(uint16_t(_config.spi->read_spi(
         unit_to_spi_adc[unit], config,
         ad7922_regs.get_reg(), 16
     )));
@@ -356,3 +298,25 @@ void x300_dboard_iface::set_command_time(const uhd::time_spec_t& t)
 {
     _config.cmd_time_ctrl->set_time(t);
 }
+
+void x300_dboard_iface::add_rx_fe(
+    const std::string& fe_name,
+    rx_frontend_core_3000::sptr fe_core)
+{
+    _rx_fes[fe_name] = fe_core;
+}
+
+void x300_dboard_iface::set_fe_connection(
+    unit_t unit, const std::string& fe_name,
+    const fe_connection_t& fe_conn)
+{
+    if (unit == UNIT_RX) {
+        if (_rx_fes.has_key(fe_name)) {
+            _rx_fes[fe_name]->set_fe_connection(fe_conn);
+        } else {
+            throw uhd::assertion_error("front-end name was not registered: " + fe_name);
+        }
+    } else {
+        throw uhd::not_implemented_error("frontend connection not configurable for TX");
+    }
+}
