@@ -26,15 +26,15 @@
 
 namespace uhd {
 
-    boost::int32_t get_process_id() {
+    int32_t get_process_id() {
 #ifdef UHD_PLATFORM_WIN32
-    return boost::int32_t(GetCurrentProcessId());
+    return int32_t(GetCurrentProcessId());
 #else
-    return boost::int32_t(getpid());
+    return int32_t(getpid());
 #endif
     }
 
-    boost::uint32_t get_host_id() {
+    uint32_t get_host_id() {
 #ifdef UHD_PLATFORM_WIN32
         //extract volume serial number
         char szVolName[MAX_PATH+1], szFileSysName[MAX_PATH+1];
@@ -43,16 +43,16 @@ namespace uhd {
             &dwSerialNumber, &dwMaxComponentLen,
             &dwFileSysFlags, szFileSysName, sizeof(szFileSysName));
 
-        return boost::uint32_t(dwSerialNumber);
+        return uint32_t(dwSerialNumber);
 #else
-        return boost::uint32_t(gethostid());
+        return uint32_t(gethostid());
 #endif
     }
 
-    boost::uint32_t get_process_hash() {
+    uint32_t get_process_hash() {
         size_t hash = 0;
         boost::hash_combine(hash, uhd::get_process_id());
         boost::hash_combine(hash, uhd::get_host_id());
-        return boost::uint32_t(hash);
+        return uint32_t(hash);
     }
 }
