@@ -32,7 +32,7 @@ public:
     task_impl(const task_fcn_type &task_fcn):
         _spawn_barrier(2)
     {
-        _thread_group.create_thread(boost::bind(&task_impl::task_loop, this, task_fcn));
+        (void)_thread_group.create_thread(boost::bind(&task_impl::task_loop, this, task_fcn));
         _spawn_barrier.wait();
     }
 
@@ -99,7 +99,7 @@ public:
     msg_task_impl(const task_fcn_type &task_fcn):
         _spawn_barrier(2)
     {
-        _thread_group.create_thread(boost::bind(&msg_task_impl::task_loop, this, task_fcn));
+        (void)_thread_group.create_thread(boost::bind(&msg_task_impl::task_loop, this, task_fcn));
         _spawn_barrier.wait();
     }
 
@@ -115,7 +115,7 @@ public:
      * This might happen during shutdown when dtors are called.
      * See also: comments in b200_io_impl->handle_async_task
      */
-    msg_payload_t get_msg_from_dump_queue(boost::uint32_t sid)
+    msg_payload_t get_msg_from_dump_queue(uint32_t sid)
     {
         boost::mutex::scoped_lock lock(_mutex);
         msg_payload_t b;
