@@ -18,7 +18,7 @@
 #include <uhd/convert.hpp>
 #include <boost/test/unit_test.hpp>
 #include <boost/foreach.hpp>
-#include <boost/cstdint.hpp>
+#include <stdint.h>
 #include <boost/assign/list_of.hpp>
 #include <complex>
 #include <vector>
@@ -28,7 +28,7 @@
 using namespace uhd;
 
 //typedefs for complex types
-typedef std::complex<boost::int16_t> sc16_t;
+typedef std::complex<int16_t> sc16_t;
 typedef std::complex<float> fc32_t;
 typedef std::complex<double> fc64_t;
 
@@ -51,7 +51,7 @@ template <typename Range> static void loopback(
     const int prio_out = -1
 ){
     //make this buffer large enough for all test types
-    std::vector<boost::uint64_t> interm(nsamps);
+    std::vector<uint64_t> interm(nsamps);
 
     std::vector<const void *> input0(1, &input[0]), input1(1, &interm[0]);
     std::vector<void *> output0(1, &interm[0]), output1(1, &output[0]);
@@ -76,8 +76,8 @@ static void test_convert_types_sc16(
     //fill the input samples
     std::vector<sc16_t> input(nsamps), output(nsamps);
     BOOST_FOREACH(sc16_t &in, input) in = sc16_t(
-        short(((std::rand()/double(RAND_MAX/2)) - 1)*32767/extra_div),
-        short(((std::rand()/double(RAND_MAX/2)) - 1)*32767/extra_div)
+        short((float((std::rand())/(double(RAND_MAX)/2)) - 1)*32767/extra_div),
+        short((float((std::rand())/(double(RAND_MAX)/2)) - 1)*32767/extra_div)
     );
 
     //run the loopback and test
@@ -127,8 +127,8 @@ static void test_convert_types_for_floats(
     //fill the input samples
     std::vector<data_type> input(nsamps), output(nsamps);
     BOOST_FOREACH(data_type &in, input) in = data_type(
-        ((std::rand()/value_type(RAND_MAX/2)) - 1)*float(extra_scale),
-        ((std::rand()/value_type(RAND_MAX/2)) - 1)*float(extra_scale)
+        ((std::rand()/(value_type(RAND_MAX)/2)) - 1)*float(extra_scale),
+        ((std::rand()/(value_type(RAND_MAX)/2)) - 1)*float(extra_scale)
     );
 
     //run the loopback and test
@@ -285,10 +285,10 @@ BOOST_AUTO_TEST_CASE(test_convert_types_fc32_to_sc16){
     const size_t nsamps = 13;
     std::vector<fc32_t> input(nsamps);
     BOOST_FOREACH(fc32_t &in, input) in = fc32_t(
-        (std::rand()/float(RAND_MAX/2)) - 1,
-        (std::rand()/float(RAND_MAX/2)) - 1
+        (std::rand()/(RAND_MAX/2.0)) - 1,
+        (std::rand()/(RAND_MAX/2.0)) - 1
     );
-    std::vector<boost::uint32_t> interm(nsamps);
+    std::vector<uint32_t> interm(nsamps);
     std::vector<sc16_t> output(nsamps);
 
     std::vector<const void *> input0(1, &input[0]), input1(1, &interm[0]);
@@ -333,7 +333,7 @@ BOOST_AUTO_TEST_CASE(test_convert_types_sc16_to_fc32){
         std::rand()-(RAND_MAX/2),
         std::rand()-(RAND_MAX/2)
     );
-    std::vector<boost::uint32_t> interm(nsamps);
+    std::vector<uint32_t> interm(nsamps);
     std::vector<fc32_t> output(nsamps);
 
     std::vector<const void *> input0(1, &input[0]), input1(1, &interm[0]);
@@ -417,16 +417,16 @@ BOOST_AUTO_TEST_CASE(test_convert_types_sc16_and_sc8){
 }
 
 /***********************************************************************
- * Test short conversion
+ * Test u8 conversion
  **********************************************************************/
 static void test_convert_types_u8(
     size_t nsamps, convert::id_type &id
 ){
     //fill the input samples
-    std::vector<boost::uint8_t> input(nsamps), output(nsamps);
-    //BOOST_FOREACH(boost::uint8_t &in, input) in = boost::uint8_t(std::rand() & 0xFF);
-    boost::uint32_t d = 48;
-    BOOST_FOREACH(boost::uint8_t &in, input) in = d++;
+    std::vector<uint8_t> input(nsamps), output(nsamps);
+    BOOST_FOREACH(uint8_t &in, input) in = uint8_t(std::rand() & 0xFF);
+    //uint32_t d = 48;
+    //BOOST_FOREACH(uint8_t &in, input) in = d++;
 
     //run the loopback and test
     convert::id_type in_id = id;
@@ -455,3 +455,163 @@ BOOST_AUTO_TEST_CASE(test_convert_types_u8_and_u8){
         test_convert_types_u8(nsamps, id);
     }
 }
+
+/***********************************************************************
+ * Test s8 conversion
+ **********************************************************************/
+static void test_convert_types_s8(
+    size_t nsamps, convert::id_type &id
+){
+    //fill the input samples
+    std::vector<int8_t> input(nsamps), output(nsamps);
+    BOOST_FOREACH(int8_t &in, input) in = int8_t(std::rand() & 0xFF);
+
+    //run the loopback and test
+    convert::id_type in_id = id;
+    convert::id_type out_id = id;
+    std::swap(out_id.input_format, out_id.output_format);
+    std::swap(out_id.num_inputs, out_id.num_outputs);
+    loopback(nsamps, in_id, out_id, input, output);
+    BOOST_CHECK_EQUAL_COLLECTIONS(input.begin(), input.end(), output.begin(), output.end());
+}
+
+BOOST_AUTO_TEST_CASE(test_convert_types_s8_and_s8){
+    convert::id_type id;
+    id.input_format = "s8";
+    id.num_inputs = 1;
+    id.num_outputs = 1;
+
+    //try various lengths to test edge cases
+    id.output_format = "s8_item32_le";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_s8(nsamps, id);
+    }
+
+    //try various lengths to test edge cases
+    id.output_format = "s8_item32_be";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_s8(nsamps, id);
+    }
+}
+
+/***********************************************************************
+ * Test s16 conversion
+ **********************************************************************/
+static void test_convert_types_s16(
+    size_t nsamps, convert::id_type &id
+){
+    //fill the input samples
+    std::vector<int16_t> input(nsamps), output(nsamps);
+    BOOST_FOREACH(int16_t &in, input) in = int16_t(std::rand() & 0xFFFF);
+
+    //run the loopback and test
+    convert::id_type in_id = id;
+    convert::id_type out_id = id;
+    std::swap(out_id.input_format, out_id.output_format);
+    std::swap(out_id.num_inputs, out_id.num_outputs);
+    loopback(nsamps, in_id, out_id, input, output);
+    BOOST_CHECK_EQUAL_COLLECTIONS(input.begin(), input.end(), output.begin(), output.end());
+}
+
+BOOST_AUTO_TEST_CASE(test_convert_types_s16_and_s16){
+    convert::id_type id;
+    id.input_format = "s16";
+    id.num_inputs = 1;
+    id.num_outputs = 1;
+
+    //try various lengths to test edge cases
+    id.output_format = "s16_item32_le";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_s16(nsamps, id);
+    }
+
+    //try various lengths to test edge cases
+    id.output_format = "s16_item32_be";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_s16(nsamps, id);
+    }
+}
+
+/***********************************************************************
+ * Test fc32 -> fc32 conversion
+ **********************************************************************/
+static void test_convert_types_fc32(
+    size_t nsamps, convert::id_type &id
+){
+    //fill the input samples
+    std::vector< std::complex<float> > input(nsamps), output(nsamps);
+    BOOST_FOREACH(fc32_t &in, input) in = fc32_t(
+        (std::rand()/float(RAND_MAX/2)) - 1,
+        (std::rand()/float(RAND_MAX/2)) - 1
+    );
+
+    //run the loopback and test
+    convert::id_type in_id = id;
+    convert::id_type out_id = id;
+    std::swap(out_id.input_format, out_id.output_format);
+    std::swap(out_id.num_inputs, out_id.num_outputs);
+    loopback(nsamps, in_id, out_id, input, output);
+    for (size_t i = 0; i < nsamps; i++){
+        MY_CHECK_CLOSE(input[i].real(), output[i].real(), float(1./(1 << 16)));
+        MY_CHECK_CLOSE(input[i].imag(), output[i].imag(), float(1./(1 << 16)));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_convert_types_fc32_and_fc32){
+    convert::id_type id;
+    id.input_format = "fc32";
+    id.num_inputs = 1;
+    id.num_outputs = 1;
+
+    //try various lengths to test edge cases
+    id.output_format = "fc32_item32_le";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_fc32(nsamps, id);
+    }
+
+    //try various lengths to test edge cases
+    id.output_format = "fc32_item32_be";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_fc32(nsamps, id);
+    }
+}
+
+/***********************************************************************
+ * Test f32 -> f32 conversion
+ **********************************************************************/
+static void test_convert_types_f32(
+    size_t nsamps, convert::id_type &id
+){
+    //fill the input samples
+    std::vector<float> input(nsamps), output(nsamps);
+    BOOST_FOREACH(float &in, input) in = float((float(std::rand())/float(RAND_MAX/2)) - 1);
+
+    //run the loopback and test
+    convert::id_type in_id = id;
+    convert::id_type out_id = id;
+    std::swap(out_id.input_format, out_id.output_format);
+    std::swap(out_id.num_inputs, out_id.num_outputs);
+    loopback(nsamps, in_id, out_id, input, output);
+    for (size_t i = 0; i < nsamps; i++){
+        MY_CHECK_CLOSE(input[i], output[i], float(1./(1 << 16)));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_convert_types_f32_and_f32){
+    convert::id_type id;
+    id.input_format = "f32";
+    id.num_inputs = 1;
+    id.num_outputs = 1;
+
+    //try various lengths to test edge cases
+    id.output_format = "f32_item32_le";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_f32(nsamps, id);
+    }
+
+    //try various lengths to test edge cases
+    id.output_format = "f32_item32_be";
+    for (size_t nsamps = 1; nsamps < 16; nsamps++){
+        test_convert_types_f32(nsamps, id);
+    }
+}
