@@ -26,7 +26,7 @@
 #include <boost/asio.hpp>
 #include <boost/program_options.hpp>
 #include <boost/assign.hpp>
-#include <boost/cstdint.hpp>
+#include <stdint.h>
 #include <boost/assign/list_of.hpp>
 #include <boost/format.hpp>
 #include <boost/filesystem.hpp>
@@ -70,20 +70,20 @@ void sig_int_handler(int){
     }
 }
 
-boost::uint8_t firmware_image[MAX_FIRMWARE_SIZE];
+uint8_t firmware_image[MAX_FIRMWARE_SIZE];
 size_t firmware_size = 0;
-boost::uint8_t octoclock_data[udp_simple::mtu];
+uint8_t octoclock_data[udp_simple::mtu];
 octoclock_packet_t *pkt_in = reinterpret_cast<octoclock_packet_t *>(octoclock_data);
 std::string firmware_path, actual_firmware_path;
 size_t num_blocks = 0;
 bool hex = true;
 
-static uint16_t calculate_crc(boost::uint8_t* buffer, boost::uint16_t len){
-    boost::uint16_t crc = 0xFFFF;
+static uint16_t calculate_crc(uint8_t* buffer, uint16_t len){
+    uint16_t crc = 0xFFFF;
 
     for(size_t i = 0; i < len; i++){
         crc ^= buffer[i];
-        for(boost::uint8_t j = 0; j < 8; ++j){
+        for(uint8_t j = 0; j < 8; ++j){
             if(crc & 1) crc = (crc >> 1) ^ 0xA001;
             else crc = (crc >> 1);
         }
@@ -123,7 +123,7 @@ void print_image_loader_warning(const std::string &fw_path, const po::variables_
               << uhd_image_loader << std::endl
               << std::endl
               << "************************************************************************************************" << std::endl
-              << std::endl; 
+              << std::endl;
 }
 
 /*
@@ -134,7 +134,7 @@ device_addrs_t bootloader_find(const std::string &ip_addr){
     udp_simple::sptr udp_transport = udp_simple::make_connected(ip_addr, BOOST_STRINGIZE(OCTOCLOCK_UDP_CTRL_PORT));
 
     octoclock_packet_t pkt_out;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
+    pkt_out.sequence = uhd::htonx<uint32_t>(std::rand());
     pkt_out.code = OCTOCLOCK_QUERY_CMD;
     pkt_out.len = 0;
     size_t len = 0;
@@ -144,7 +144,7 @@ device_addrs_t bootloader_find(const std::string &ip_addr){
     boost::system_time comm_timeout = boost::get_system_time() + boost::posix_time::milliseconds(3000);
 
     while(boost::get_system_time() < comm_timeout){
-        UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
+        UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
         if(UHD_OCTOCLOCK_PACKET_MATCHES(OCTOCLOCK_QUERY_ACK, pkt_out, pkt_in, len) and
            pkt_in->proto_ver == OCTOCLOCK_BOOTLOADER_PROTO_VER){
             addrs.push_back(device_addr_t());
@@ -174,14 +174,14 @@ void read_firmware(){
 
 void burn_firmware(udp_simple::sptr udp_transport){
     octoclock_packet_t pkt_out;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
-    pkt_out.len = (boost::uint16_t)firmware_size;
+    pkt_out.sequence = uhd::htonx<uint32_t>(std::rand());
+    pkt_out.len = (uint16_t)firmware_size;
     pkt_out.crc = calculate_crc(firmware_image, firmware_size);
     size_t len = 0, current_pos = 0;
 
     //Tell OctoClock not to jump to application, wait for us instead
     std::cout << "Telling OctoClock to prepare for firmware download..." << std::flush;
-    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, PREPARE_FW_BURN_CMD, pkt_out, len, octoclock_data);
+    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, PREPARE_FW_BURN_CMD, pkt_out, len, octoclock_data);
     if(UHD_OCTOCLOCK_PACKET_MATCHES(FW_BURN_READY_ACK, pkt_out, pkt_in, len)) std::cout << "ready." << std::endl;
     else{
         std::cout << std::endl;
@@ -206,7 +206,7 @@ void burn_firmware(udp_simple::sptr udp_transport){
 
         bool success = false;
         while(num_tries <= 5){
-            UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, FILE_TRANSFER_CMD, pkt_out, len, octoclock_data);
+            UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, FILE_TRANSFER_CMD, pkt_out, len, octoclock_data);
             if(UHD_OCTOCLOCK_PACKET_MATCHES(FILE_TRANSFER_ACK, pkt_out, pkt_in, len)){
                 success = true;
                 break;
@@ -231,7 +231,7 @@ void burn_firmware(udp_simple::sptr udp_transport){
 void verify_firmware(udp_simple::sptr udp_transport){
     octoclock_packet_t pkt_out;
     pkt_out.proto_ver = OCTOCLOCK_FW_COMPAT_NUM;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
+    pkt_out.sequence = uhd::htonx<uint32_t>(std::rand());
     size_t len = 0, current_pos = 0;
 
     for(size_t i = 0; i < num_blocks; i++){
@@ -240,7 +240,7 @@ void verify_firmware(udp_simple::sptr udp_transport){
         std::cout << "\r * Progress: " << int(double(i)/double(num_blocks)*100)
                   << "% (" << (i+1) << "/" << num_blocks << " blocks)" << std::flush;
 
-        UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, READ_FW_CMD, pkt_out, len, octoclock_data);
+        UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, READ_FW_CMD, pkt_out, len, octoclock_data);
         if(UHD_OCTOCLOCK_PACKET_MATCHES(READ_FW_ACK, pkt_out, pkt_in, len)){
             if(memcmp((void*)(pkt_in->data), &firmware_image[i*BLOCK_SIZE],
                       std::min(int(firmware_size-current_pos), BLOCK_SIZE))){
@@ -263,10 +263,10 @@ bool reset_octoclock(const std::string &ip_addr){
     udp_simple::sptr udp_transport = udp_simple::make_connected(ip_addr, BOOST_STRINGIZE(OCTOCLOCK_UDP_CTRL_PORT));
 
     octoclock_packet_t pkt_out;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
+    pkt_out.sequence = uhd::htonx<uint32_t>(std::rand());
     size_t len;
 
-    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, RESET_CMD, pkt_out, len, octoclock_data);
+    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, RESET_CMD, pkt_out, len, octoclock_data);
     if(not UHD_OCTOCLOCK_PACKET_MATCHES(RESET_ACK, pkt_out, pkt_in, len)){
         std::cout << std::endl;
         if(hex) fs::remove(actual_firmware_path);
@@ -280,10 +280,10 @@ bool reset_octoclock(const std::string &ip_addr){
 void finalize(udp_simple::sptr udp_transport){
     octoclock_packet_t pkt_out;
     pkt_out.len = 0;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
+    pkt_out.sequence = uhd::htonx<uint32_t>(std::rand());
     size_t len = 0;
 
-    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, FINALIZE_BURNING_CMD, pkt_out, len, octoclock_data);
+    UHD_OCTOCLOCK_SEND_AND_RECV(udp_transport, OCTOCLOCK_FW_COMPAT_NUM, FINALIZE_BURNING_CMD, pkt_out, len, octoclock_data);
     if(not UHD_OCTOCLOCK_PACKET_MATCHES(FINALIZE_BURNING_ACK, pkt_out, pkt_in, len)){
         std::cout << std::endl;
         if(hex) fs::remove(actual_firmware_path);
