@@ -116,7 +116,7 @@ int UHD_SAFE_MAIN(int argc, char *argv[])
         ("verbose", "enable some verbose")
         ("args", po::value<std::string>(&args)->default_value(""), "Device address args [default = \"\"]")
         ("subdev", po::value<std::string>(&subdev), "Subdevice specification (default: first subdevice, often 'A')")
-        ("tx_wave_ampl", po::value<double>(&tx_wave_ampl)->default_value(0.7), "Transmit wave amplitude in counts")
+        ("tx_wave_ampl", po::value<double>(&tx_wave_ampl)->default_value(0.7), "Transmit wave amplitude")
         ("tx_offset", po::value<double>(&tx_offset)->default_value(.9344e6), "TX LO offset from the RX LO in Hz")
         ("freq_start", po::value<double>(&freq_start), "Frequency start in Hz (do not specify for default)")
         ("freq_stop", po::value<double>(&freq_stop), "Frequency stop in Hz (do not specify for default)")
